# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.environment.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_spec__pb2
from ai.stigmer.agentic.workflow.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_workflow_dot_v1_dot_enum__pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ai/stigmer/agentic/workflow/v1/spec.proto\x12\x1e\x61i.stigmer.agentic.workflow.v1\x1a,ai/stigmer/agentic/environment/v1/spec.proto\x1a)ai/stigmer/agentic/workflow/v1/enum.proto\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa3\x02\n\x0cWorkflowSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12T\n\x08\x64ocument\x18\x02 \x01(\x0b\x32\x30.ai.stigmer.agentic.workflow.v1.WorkflowDocumentB\x06\xbaH\x03\xc8\x01\x01R\x08\x64ocument\x12L\n\x05tasks\x18\x03 \x03(\x0b\x32,.ai.stigmer.agentic.workflow.v1.WorkflowTaskB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x05tasks\x12M\n\x08\x65nv_spec\x18\x04 \x01(\x0b\x32\x32.ai.stigmer.agentic.environment.v1.EnvironmentSpecR\x07\x65nvSpec\"\xbc\x01\n\x10WorkflowDocument\x12\"\n\x03\x64sl\x18\x01 \x01(\tB\x10\xbaH\rr\x0b\x32\t^1\\.0\\.0$R\x03\x64sl\x12$\n\tnamespace\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tnamespace\x12\x1a\n\x04name\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\x12 \n\x07version\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07version\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\"\xc3\x02\n\x0cWorkflowTask\x12\x1a\n\x04name\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\x12L\n\x04kind\x18\x02 \x01(\x0e\x32\x30.ai.stigmer.agentic.workflow.v1.WorkflowTaskKindB\x06\xbaH\x03\xc8\x01\x01R\x04kind\x12H\n\x0btask_config\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x0e\xbaH\x03\xc8\x01\x01\xea\x85,\x04kindR\ntaskConfig\x12>\n\x06\x65xport\x18\x04 \x01(\x0b\x32&.ai.stigmer.agentic.workflow.v1.ExportR\x06\x65xport\x12?\n\x04\x66low\x18\x05 \x01(\x0b\x32+.ai.stigmer.agentic.workflow.v1.FlowControlR\x04\x66low\"!\n\x06\x45xport\x12\x17\n\x02\x61s\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02\x61s\"!\n\x0b\x46lowControl\x12\x12\n\x04then\x18\x01 \x01(\tR\x04thenB\xcc\x01\n\"com.ai.stigmer.agentic.workflow.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\x1e\x41i.Stigmer.Agentic.Workflow.V1\xca\x02\x1e\x41i\\Stigmer\\Agentic\\Workflow\\V1\xe2\x02*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\xea\x02\"Ai::Stigmer::Agentic::Workflow::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.agentic.workflow.v1B\tSpecProtoP\001\242\002\004ASAW\252\002\036Ai.Stigmer.Agentic.Workflow.V1\312\002\036Ai\\Stigmer\\Agentic\\Workflow\\V1\342\002*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\352\002\"Ai::Stigmer::Agentic::Workflow::V1'
  _globals['_WORKFLOWSPEC'].fields_by_name['document']._loaded_options = None
  _globals['_WORKFLOWSPEC'].fields_by_name['document']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWSPEC'].fields_by_name['tasks']._loaded_options = None
  _globals['_WORKFLOWSPEC'].fields_by_name['tasks']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_WORKFLOWDOCUMENT'].fields_by_name['dsl']._loaded_options = None
  _globals['_WORKFLOWDOCUMENT'].fields_by_name['dsl']._serialized_options = b'\272H\rr\0132\t^1\\.0\\.0$'
  _globals['_WORKFLOWDOCUMENT'].fields_by_name['namespace']._loaded_options = None
  _globals['_WORKFLOWDOCUMENT'].fields_by_name['namespace']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWDOCUMENT'].fields_by_name['name']._loaded_options = None
  _globals['_WORKFLOWDOCUMENT'].fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWDOCUMENT'].fields_by_name['version']._loaded_options = None
  _globals['_WORKFLOWDOCUMENT'].fields_by_name['version']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWTASK'].fields_by_name['name']._loaded_options = None
  _globals['_WORKFLOWTASK'].fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWTASK'].fields_by_name['kind']._loaded_options = None
  _globals['_WORKFLOWTASK'].fields_by_name['kind']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWTASK'].fields_by_name['task_config']._loaded_options = None
  _globals['_WORKFLOWTASK'].fields_by_name['task_config']._serialized_options = b'\272H\003\310\001\001\352\205,\004kind'
  _globals['_EXPORT'].fields_by_name['as']._loaded_options = None
  _globals['_EXPORT'].fields_by_name['as']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WORKFLOWSPEC']._serialized_start=278
  _globals['_WORKFLOWSPEC']._serialized_end=569
  _globals['_WORKFLOWDOCUMENT']._serialized_start=572
  _globals['_WORKFLOWDOCUMENT']._serialized_end=760
  _globals['_WORKFLOWTASK']._serialized_start=763
  _globals['_WORKFLOWTASK']._serialized_end=1086
  _globals['_EXPORT']._serialized_start=1088
  _globals['_EXPORT']._serialized_end=1121
  _globals['_FLOWCONTROL']._serialized_start=1123
  _globals['_FLOWCONTROL']._serialized_end=1156
# @@protoc_insertion_point(module_scope)
