# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/mcpserver/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/mcpserver/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.mcpserver.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_spec__pb2
from ai.stigmer.agentic.mcpserver.v1 import status_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_status__pb2
from ai.stigmer.commons.apiresource import metadata_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_metadata__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ai/stigmer/agentic/mcpserver/v1/api.proto\x12\x1f\x61i.stigmer.agentic.mcpserver.v1\x1a*ai/stigmer/agentic/mcpserver/v1/spec.proto\x1a,ai/stigmer/agentic/mcpserver/v1/status.proto\x1a-ai/stigmer/commons/apiresource/metadata.proto\x1a\x1b\x62uf/validate/validate.proto\"\xd7\x02\n\tMcpServer\x12=\n\x0b\x61pi_version\x18\x01 \x01(\tB\x1c\xbaH\x19r\x17\n\x15\x61gentic.stigmer.ai/v1R\napiVersion\x12$\n\x04kind\x18\x02 \x01(\tB\x10\xbaH\rr\x0b\n\tMcpServerR\x04kind\x12W\n\x08metadata\x18\x03 \x01(\x0b\x32\x33.ai.stigmer.commons.apiresource.ApiResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x42\n\x04spec\x18\x04 \x01(\x0b\x32..ai.stigmer.agentic.mcpserver.v1.McpServerSpecR\x04spec\x12H\n\x06status\x18\x05 \x01(\x0b\x32\x30.ai.stigmer.agentic.mcpserver.v1.McpServerStatusR\x06status\"\x86\x01\n\rMcpServerList\x12\x1f\n\x0b\x61pi_version\x18\x01 \x01(\tR\napiVersion\x12\x12\n\x04kind\x18\x02 \x01(\tR\x04kind\x12@\n\x05items\x18\x03 \x03(\x0b\x32*.ai.stigmer.agentic.mcpserver.v1.McpServerR\x05itemsB\xd0\x01\n#com.ai.stigmer.agentic.mcpserver.v1B\x08\x41piProtoP\x01\xa2\x02\x04\x41SAM\xaa\x02\x1f\x41i.Stigmer.Agentic.Mcpserver.V1\xca\x02\x1f\x41i\\Stigmer\\Agentic\\Mcpserver\\V1\xe2\x02+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\xea\x02#Ai::Stigmer::Agentic::Mcpserver::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.mcpserver.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.ai.stigmer.agentic.mcpserver.v1B\010ApiProtoP\001\242\002\004ASAM\252\002\037Ai.Stigmer.Agentic.Mcpserver.V1\312\002\037Ai\\Stigmer\\Agentic\\Mcpserver\\V1\342\002+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\352\002#Ai::Stigmer::Agentic::Mcpserver::V1'
  _globals['_MCPSERVER'].fields_by_name['api_version']._loaded_options = None
  _globals['_MCPSERVER'].fields_by_name['api_version']._serialized_options = b'\272H\031r\027\n\025agentic.stigmer.ai/v1'
  _globals['_MCPSERVER'].fields_by_name['kind']._loaded_options = None
  _globals['_MCPSERVER'].fields_by_name['kind']._serialized_options = b'\272H\rr\013\n\tMcpServer'
  _globals['_MCPSERVER'].fields_by_name['metadata']._loaded_options = None
  _globals['_MCPSERVER'].fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _globals['_MCPSERVER']._serialized_start=245
  _globals['_MCPSERVER']._serialized_end=588
  _globals['_MCPSERVERLIST']._serialized_start=591
  _globals['_MCPSERVERLIST']._serialized_end=725
# @@protoc_insertion_point(module_scope)
