# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/rpcauthorization/iam_permission.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/rpcauthorization/iam_permission.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAai/stigmer/iam/iampolicy/v1/rpcauthorization/iam_permission.proto\x12,ai.stigmer.iam.iampolicy.v1.rpcauthorization*\xa0\x05\n\x18\x41piResourceIamPermission\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63reate\x10\x01\x12\x0e\n\ncan_delete\x10\x02\x12\x0c\n\x08\x63\x61n_view\x10\x03\x12\x0c\n\x08\x63\x61n_edit\x10\x04\x12\x18\n\x14login_to_back_office\x10\x07\x12\x14\n\x10\x63\x61n_grant_access\x10\x08\x12\x13\n\x0f\x63\x61n_view_access\x10\t\x12\t\n\x05owner\x10\n\x12\n\n\x06member\x10\x0b\x12\n\n\x06viewer\x10\x1a\x12\x14\n\x10identity_account\x10\x0c\x12\x10\n\x0corganization\x10\r\x12\x0b\n\x07session\x10\x0e\x12\t\n\x05\x61gent\x10\x0f\x12\x14\n\x10\x63\x61n_create_agent\x10\x10\x12\x17\n\x13\x63\x61n_create_workflow\x10\x11\x12\x16\n\x12\x63\x61n_create_session\x10\x12\x12\x1b\n\x17\x63\x61n_create_execution_in\x10\x13\x12\x17\n\x13\x63\x61n_create_instance\x10\x14\x12\x14\n\x10\x63\x61n_create_skill\x10\x15\x12\x16\n\x12\x63\x61n_create_project\x10\x17\x12\x12\n\x0e\x63\x61n_create_idp\x10\x18\x12\x1a\n\x16\x63\x61n_create_environment\x10\x1b\x12\x0f\n\x0b\x63\x61n_execute\x10\x16\x12\x14\n\x10\x63\x61n_read_secrets\x10\x19\x12\x15\n\x11\x63\x61n_bootstrap_iam\x10\x1d\x12 \n\x1c\x63\x61n_manage_identity_accounts\x10\x1e\x12\x1f\n\x1b\x63\x61n_update_execution_status\x10\x1f\"\x04\x08\x05\x10\x05\"\x04\x08\x06\x10\x06\"\x04\x08\x1c\x10\x1c*\x08operator*\x08platform*\x11\x63\x61n_update_statusB\x9e\x02\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\x12IamPermissionProtoP\x01\xa2\x02\x06\x41SIIVR\xaa\x02,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\xca\x02,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\xe2\x02\x38\x41i\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\xea\x02\x31\x41i::Stigmer::Iam::Iampolicy::V1::Rpcauthorizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.rpcauthorization.iam_permission_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\022IamPermissionProtoP\001\242\002\006ASIIVR\252\002,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\312\002,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\342\0028Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\352\0021Ai::Stigmer::Iam::Iampolicy::V1::Rpcauthorization'
  _globals['_APIRESOURCEIAMPERMISSION']._serialized_start=116
  _globals['_APIRESOURCEIAMPERMISSION']._serialized_end=788
# @@protoc_insertion_point(module_scope)
