# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/tasks/grpc_call.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/tasks/grpc_call.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ai/stigmer/agentic/workflow/v1/tasks/grpc_call.proto\x12$ai.stigmer.agentic.workflow.v1.tasks\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa0\x01\n\x12GrpcCallTaskConfig\x12$\n\x07service\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x07service\x12\"\n\x06method\x18\x02 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x06method\x12\x31\n\x07request\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07request:\r\xea\x8b,\tgrpc_callB\xf1\x01\n(com.ai.stigmer.agentic.workflow.v1.tasksB\rGrpcCallProtoP\x01\xa2\x02\x06\x41SAWVT\xaa\x02$Ai.Stigmer.Agentic.Workflow.V1.Tasks\xca\x02$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\xea\x02)Ai::Stigmer::Agentic::Workflow::V1::Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.tasks.grpc_call_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.workflow.v1.tasksB\rGrpcCallProtoP\001\242\002\006ASAWVT\252\002$Ai.Stigmer.Agentic.Workflow.V1.Tasks\312\002$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\342\0020Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\352\002)Ai::Stigmer::Agentic::Workflow::V1::Tasks'
  _globals['_GRPCCALLTASKCONFIG'].fields_by_name['service']._loaded_options = None
  _globals['_GRPCCALLTASKCONFIG'].fields_by_name['service']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_GRPCCALLTASKCONFIG'].fields_by_name['method']._loaded_options = None
  _globals['_GRPCCALLTASKCONFIG'].fields_by_name['method']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_GRPCCALLTASKCONFIG']._loaded_options = None
  _globals['_GRPCCALLTASKCONFIG']._serialized_options = b'\352\213,\tgrpc_call'
  _globals['_GRPCCALLTASKCONFIG']._serialized_start=206
  _globals['_GRPCCALLTASKCONFIG']._serialized_end=366
# @@protoc_insertion_point(module_scope)
