# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/skill/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/skill/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ai/stigmer/agentic/skill/v1/spec.proto\x12\x1b\x61i.stigmer.agentic.skill.v1\x1a\x1b\x62uf/validate/validate.proto\"\xbb\x01\n\tSkillSpec\x12\"\n\x08skill_md\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07skillMd\x12-\n\x03tag\x18\x02 \x01(\tB\x1b\xbaH\x18r\x16\x32\x14^$|^[a-zA-Z0-9._-]+$R\x03tag\x12\x33\n\x04name\x18\x03 \x01(\tB\x1f\xbaH\x1cr\x1a\x32\x18^[a-z0-9]+(-[a-z0-9]+)*$R\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scriptionJ\x04\x08\x04\x10\x05\x42\xbd\x01\n\x1f\x63om.ai.stigmer.agentic.skill.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1b\x41i.Stigmer.Agentic.Skill.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Skill\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Skill::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.skill.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.skill.v1B\tSpecProtoP\001\242\002\004ASAS\252\002\033Ai.Stigmer.Agentic.Skill.V1\312\002\033Ai\\Stigmer\\Agentic\\Skill\\V1\342\002\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Skill::V1'
  _globals['_SKILLSPEC'].fields_by_name['skill_md']._loaded_options = None
  _globals['_SKILLSPEC'].fields_by_name['skill_md']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SKILLSPEC'].fields_by_name['tag']._loaded_options = None
  _globals['_SKILLSPEC'].fields_by_name['tag']._serialized_options = b'\272H\030r\0262\024^$|^[a-zA-Z0-9._-]+$'
  _globals['_SKILLSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_SKILLSPEC'].fields_by_name['name']._serialized_options = b'\272H\034r\0322\030^[a-z0-9]+(-[a-z0-9]+)*$'
  _globals['_SKILLSPEC']._serialized_start=101
  _globals['_SKILLSPEC']._serialized_end=288
# @@protoc_insertion_point(module_scope)
