# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/organization/v1/enum.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/organization/v1/enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/tenancy/organization/v1/enum.proto\x12\"ai.stigmer.tenancy.organization.v1*Y\n\x0eManagementMode\x12\x1f\n\x1bmanagement_mode_unspecified\x10\x00\x12\x10\n\x0cself_managed\x10\x01\x12\x14\n\x10platform_managed\x10\x02\x42\xe0\x01\n&com.ai.stigmer.tenancy.organization.v1B\tEnumProtoP\x01\xa2\x02\x04\x41STO\xaa\x02\"Ai.Stigmer.Tenancy.Organization.V1\xca\x02\"Ai\\Stigmer\\Tenancy\\Organization\\V1\xe2\x02.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\xea\x02&Ai::Stigmer::Tenancy::Organization::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.organization.v1.enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.ai.stigmer.tenancy.organization.v1B\tEnumProtoP\001\242\002\004ASTO\252\002\"Ai.Stigmer.Tenancy.Organization.V1\312\002\"Ai\\Stigmer\\Tenancy\\Organization\\V1\342\002.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\352\002&Ai::Stigmer::Tenancy::Organization::V1'
  _globals['_MANAGEMENTMODE']._serialized_start=85
  _globals['_MANAGEMENTMODE']._serialized_end=174
# @@protoc_insertion_point(module_scope)
