# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/organization/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/organization/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.tenancy.organization.v1 import api_pb2 as ai_dot_stigmer_dot_tenancy_dot_organization_dot_v1_dot_api__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ai/stigmer/tenancy/organization/v1/io.proto\x12\"ai.stigmer.tenancy.organization.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a,ai/stigmer/tenancy/organization/v1/api.proto\x1a\x1b\x62uf/validate/validate.proto\"[\n\rOrganizations\x12J\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x30.ai.stigmer.tenancy.organization.v1.OrganizationR\x07\x65ntries\"\x7f\n\x10OrganizationList\x12\x1f\n\x0btotal_pages\x18\x01 \x01(\x05R\ntotalPages\x12J\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x30.ai.stigmer.tenancy.organization.v1.OrganizationR\x07\x65ntries\"1\n\x0eOrganizationId\x12\x1f\n\x05value\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18@R\x05value\"\xbf\x01\n\x1aOrganizationExternalLookup\x12p\n\x15identity_provider_ref\x18\x01 \x01(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceB\x06\xbaH\x03\xc8\x01\x01R\x13identityProviderRef\x12/\n\x0f\x65xternal_org_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\rexternalOrgIdB\xde\x01\n&com.ai.stigmer.tenancy.organization.v1B\x07IoProtoP\x01\xa2\x02\x04\x41STO\xaa\x02\"Ai.Stigmer.Tenancy.Organization.V1\xca\x02\"Ai\\Stigmer\\Tenancy\\Organization\\V1\xe2\x02.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\xea\x02&Ai::Stigmer::Tenancy::Organization::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.organization.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.ai.stigmer.tenancy.organization.v1B\007IoProtoP\001\242\002\004ASTO\252\002\"Ai.Stigmer.Tenancy.Organization.V1\312\002\"Ai\\Stigmer\\Tenancy\\Organization\\V1\342\002.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\352\002&Ai::Stigmer::Tenancy::Organization::V1'
  _globals['_ORGANIZATIONID'].fields_by_name['value']._loaded_options = None
  _globals['_ORGANIZATIONID'].fields_by_name['value']._serialized_options = b'\272H\006r\004\020\001\030@'
  _globals['_ORGANIZATIONEXTERNALLOOKUP'].fields_by_name['identity_provider_ref']._loaded_options = None
  _globals['_ORGANIZATIONEXTERNALLOOKUP'].fields_by_name['identity_provider_ref']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ORGANIZATIONEXTERNALLOOKUP'].fields_by_name['external_org_id']._loaded_options = None
  _globals['_ORGANIZATIONEXTERNALLOOKUP'].fields_by_name['external_org_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ORGANIZATIONS']._serialized_start=199
  _globals['_ORGANIZATIONS']._serialized_end=290
  _globals['_ORGANIZATIONLIST']._serialized_start=292
  _globals['_ORGANIZATIONLIST']._serialized_end=419
  _globals['_ORGANIZATIONID']._serialized_start=421
  _globals['_ORGANIZATIONID']._serialized_end=470
  _globals['_ORGANIZATIONEXTERNALLOOKUP']._serialized_start=473
  _globals['_ORGANIZATIONEXTERNALLOOKUP']._serialized_end=664
# @@protoc_insertion_point(module_scope)
