# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowexecution/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowexecution/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflowexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowexecution.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ai/stigmer/agentic/workflowexecution/v1/command.proto\x12\'ai.stigmer.agentic.workflowexecution.v1\x1a\x31\x61i/stigmer/agentic/workflowexecution/v1/api.proto\x1a\x30\x61i/stigmer/agentic/workflowexecution/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xaa\x11\n\"WorkflowExecutionCommandController\x12\x86\x01\n\x06\x63reate\x12:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"\x04\xd0\xb8\x18\x01\x12\xc2\x01\n\x06update\x12:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"@\xc2\xb8\x18<\x08\x04\x10\x34\"\x0bmetadata.id*)unauthorized to update workflow execution\x12\xdc\x01\n\x0cupdateStatus\x12K.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionUpdateStatusInput\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"C\xc2\xb8\x18?\x08\x1f\x10\x1f*0unauthorized to update workflow execution status2\x07stigmer\x12\xe2\x01\n\x0esubmitApproval\x12\x44.ai.stigmer.agentic.workflowexecution.v1.SubmitWorkflowApprovalInput\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"N\xc2\xb8\x18J\x08\x04\x10\x34\"\x0c\x65xecution_id*6unauthorized to submit approval for workflow execution\x12\xaf\x01\n\x06\x64\x65lete\x12-.ai.stigmer.commons.apiresource.ApiResourceId\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\":\xc2\xb8\x18\x36\x08\x04\x10\x34\"\x05value*)unauthorized to delete workflow execution\x12\xcd\x01\n\nsendSignal\x12\x38.ai.stigmer.agentic.workflowexecution.v1.SendSignalInput\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"I\xc2\xb8\x18\x45\x08\x04\x10\x34\"\x0c\x65xecution_id*1unauthorized to send signal to workflow execution\x12\xc4\x01\n\x06\x63\x61ncel\x12\x45.ai.stigmer.agentic.workflowexecution.v1.CancelWorkflowExecutionInput\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"7\xc2\xb8\x18\x33\x08\x04\x10\x34\"\x02id*)unauthorized to cancel workflow execution\x12\xcd\x01\n\tterminate\x12H.ai.stigmer.agentic.workflowexecution.v1.TerminateWorkflowExecutionInput\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\":\xc2\xb8\x18\x36\x08\x04\x10\x34\"\x02id*,unauthorized to terminate workflow execution\x12\xc7\x01\n\x07recover\x12\x46.ai.stigmer.agentic.workflowexecution.v1.RecoverWorkflowExecutionInput\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"8\xc2\xb8\x18\x34\x08\x04\x10\x34\"\x02id**unauthorized to recover workflow execution\x12\xc1\x01\n\x05pause\x12\x44.ai.stigmer.agentic.workflowexecution.v1.PauseWorkflowExecutionInput\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"6\xc2\xb8\x18\x32\x08\x04\x10\x34\"\x02id*(unauthorized to pause workflow execution\x12\xc4\x01\n\x06resume\x12\x45.ai.stigmer.agentic.workflowexecution.v1.ResumeWorkflowExecutionInput\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"7\xc2\xb8\x18\x33\x08\x04\x10\x34\"\x02id*)unauthorized to resume workflow execution\x1a\x04\xa0\xff+4B\xfc\x01\n+com.ai.stigmer.agentic.workflowexecution.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\'Ai.Stigmer.Agentic.Workflowexecution.V1\xca\x02\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\xe2\x02\x33\x41i\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\xea\x02+Ai::Stigmer::Agentic::Workflowexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowexecution.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.ai.stigmer.agentic.workflowexecution.v1B\014CommandProtoP\001\242\002\004ASAW\252\002\'Ai.Stigmer.Agentic.Workflowexecution.V1\312\002\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\342\0023Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\352\002+Ai::Stigmer::Agentic::Workflowexecution::V1'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER']._serialized_options = b'\240\377+4'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\320\270\030\001'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\030<\010\004\0204\"\013metadata.id*)unauthorized to update workflow execution'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['updateStatus']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['updateStatus']._serialized_options = b'\302\270\030?\010\037\020\037*0unauthorized to update workflow execution status2\007stigmer'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['submitApproval']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['submitApproval']._serialized_options = b'\302\270\030J\010\004\0204\"\014execution_id*6unauthorized to submit approval for workflow execution'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\0306\010\004\0204\"\005value*)unauthorized to delete workflow execution'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['sendSignal']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['sendSignal']._serialized_options = b'\302\270\030E\010\004\0204\"\014execution_id*1unauthorized to send signal to workflow execution'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['cancel']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['cancel']._serialized_options = b'\302\270\0303\010\004\0204\"\002id*)unauthorized to cancel workflow execution'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['terminate']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['terminate']._serialized_options = b'\302\270\0306\010\004\0204\"\002id*,unauthorized to terminate workflow execution'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['recover']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['recover']._serialized_options = b'\302\270\0304\010\004\0204\"\002id**unauthorized to recover workflow execution'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['pause']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['pause']._serialized_options = b'\302\270\0302\010\004\0204\"\002id*(unauthorized to pause workflow execution'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['resume']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER'].methods_by_name['resume']._serialized_options = b'\302\270\0303\010\004\0204\"\002id*)unauthorized to resume workflow execution'
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER']._serialized_start=366
  _globals['_WORKFLOWEXECUTIONCOMMANDCONTROLLER']._serialized_end=2584
# @@protoc_insertion_point(module_scope)
