# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/session/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/session/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agent.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_spec__pb2
from ai.stigmer.agentic.session.v1 import workspace_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_workspace__pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/stigmer/agentic/session/v1/spec.proto\x12\x1d\x61i.stigmer.agentic.session.v1\x1a&ai/stigmer/agentic/agent/v1/spec.proto\x1a-ai/stigmer/agentic/session/v1/workspace.proto\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x1b\x62uf/validate/validate.proto\"\xb1\x06\n\x0bSessionSpec\x12*\n\x11\x61gent_instance_id\x18\x01 \x01(\tR\x0f\x61gentInstanceId\x12\x18\n\x07subject\x18\x02 \x01(\tR\x07subject\x12\x1b\n\tthread_id\x18\x03 \x01(\tR\x08threadId\x12\x1d\n\nsandbox_id\x18\x04 \x01(\tR\tsandboxId\x12T\n\x08metadata\x18\x05 \x03(\x0b\x32\x38.ai.stigmer.agentic.session.v1.SessionSpec.MetadataEntryR\x08metadata\x12Z\n\x11workspace_entries\x18\x06 \x03(\x0b\x32-.ai.stigmer.agentic.session.v1.WorkspaceEntryR\x10workspaceEntries\x12\xea\x01\n\x11mcp_server_usages\x18\x07 \x03(\x0b\x32+.ai.stigmer.agentic.agent.v1.McpServerUsageB\x90\x01\xbaH\x8c\x01\x92\x01\x88\x01\"\x85\x01\xba\x01\x81\x01\n\x1esession_mcp_server_usages.kind\x12?mcp_server_usages must reference resources with kind=mcp_server\x1a\x1ethis.mcp_server_ref.kind == 44R\x0fmcpServerUsages\x12\xc3\x01\n\nskill_refs\x18\x08 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceBn\xbaHg\x92\x01\x64\"b\xba\x01_\n\x17session_skill_refs.kind\x12\x33skill_refs must reference resources with kind=skill\x1a\x0fthis.kind == 43\xe0\x85,+R\tskillRefs\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xc7\x01\n!com.ai.stigmer.agentic.session.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1d\x41i.Stigmer.Agentic.Session.V1\xca\x02\x1d\x41i\\Stigmer\\Agentic\\Session\\V1\xe2\x02)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Agentic::Session::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.session.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.agentic.session.v1B\tSpecProtoP\001\242\002\004ASAS\252\002\035Ai.Stigmer.Agentic.Session.V1\312\002\035Ai\\Stigmer\\Agentic\\Session\\V1\342\002)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\352\002!Ai::Stigmer::Agentic::Session::V1'
  _globals['_SESSIONSPEC_METADATAENTRY']._loaded_options = None
  _globals['_SESSIONSPEC_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SESSIONSPEC'].fields_by_name['mcp_server_usages']._loaded_options = None
  _globals['_SESSIONSPEC'].fields_by_name['mcp_server_usages']._serialized_options = b'\272H\214\001\222\001\210\001\"\205\001\272\001\201\001\n\036session_mcp_server_usages.kind\022?mcp_server_usages must reference resources with kind=mcp_server\032\036this.mcp_server_ref.kind == 44'
  _globals['_SESSIONSPEC'].fields_by_name['skill_refs']._loaded_options = None
  _globals['_SESSIONSPEC'].fields_by_name['skill_refs']._serialized_options = b'\272Hg\222\001d\"b\272\001_\n\027session_skill_refs.kind\0223skill_refs must reference resources with kind=skill\032\017this.kind == 43\340\205,+'
  _globals['_SESSIONSPEC']._serialized_start=285
  _globals['_SESSIONSPEC']._serialized_end=1102
  _globals['_SESSIONSPEC_METADATAENTRY']._serialized_start=1043
  _globals['_SESSIONSPEC_METADATAENTRY']._serialized_end=1102
# @@protoc_insertion_point(module_scope)
