# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/subagent.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/subagent.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import approval_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_approval__pb2
from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_enum__pb2
from ai.stigmer.agentic.agentexecution.v1 import message_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_message__pb2
from ai.stigmer.agentic.agentexecution.v1 import usage_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_usage__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3ai/stigmer/agentic/agentexecution/v1/subagent.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a\x33\x61i/stigmer/agentic/agentexecution/v1/approval.proto\x1a/ai/stigmer/agentic/agentexecution/v1/enum.proto\x1a\x32\x61i/stigmer/agentic/agentexecution/v1/message.proto\x1a\x30\x61i/stigmer/agentic/agentexecution/v1/usage.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xb1\x05\n\x11SubAgentExecution\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x14\n\x05input\x18\x03 \x01(\tR\x05input\x12\x16\n\x06output\x18\x04 \x01(\tR\x06output\x12V\n\x06status\x18\x05 \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.SubAgentStatusB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x06status\x12\x1d\n\nstarted_at\x18\x06 \x01(\tR\tstartedAt\x12!\n\x0c\x63ompleted_at\x18\x07 \x01(\tR\x0b\x63ompletedAt\x12\x14\n\x05\x65rror\x18\x08 \x01(\tR\x05\x65rror\x12\x33\n\x08metadata\x18\t \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\x12M\n\ntool_calls\x18\n \x03(\x0b\x32..ai.stigmer.agentic.agentexecution.v1.ToolCallR\ttoolCalls\x12N\n\x08messages\x18\x0b \x03(\x0b\x32\x32.ai.stigmer.agentic.agentexecution.v1.AgentMessageR\x08messages\x12H\n\x05usage\x18\x0c \x01(\x0b\x32\x32.ai.stigmer.agentic.agentexecution.v1.UsageMetricsR\x05usage\x12\x18\n\x07subject\x18\r \x01(\tR\x07subject\x12\x62\n\x11pending_approvals\x18\x0e \x03(\x0b\x32\x35.ai.stigmer.agentic.agentexecution.v1.PendingApprovalR\x10pendingApprovalsB\xee\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\rSubagentProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.subagent_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\rSubagentProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_SUBAGENTEXECUTION'].fields_by_name['status']._loaded_options = None
  _globals['_SUBAGENTEXECUTION'].fields_by_name['status']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_SUBAGENTEXECUTION']._serialized_start=357
  _globals['_SUBAGENTEXECUTION']._serialized_end=1046
# @@protoc_insertion_point(module_scope)
