# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/project/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/project/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2
from ai.stigmer.tenancy.project.v1 import api_pb2 as ai_dot_stigmer_dot_tenancy_dot_project_dot_v1_dot_api__pb2
from ai.stigmer.tenancy.project.v1 import io_pb2 as ai_dot_stigmer_dot_tenancy_dot_project_dot_v1_dot_io__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ai/stigmer/tenancy/project/v1/command.proto\x12\x1d\x61i.stigmer.tenancy.project.v1\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto\x1a\'ai/stigmer/tenancy/project/v1/api.proto\x1a&ai/stigmer/tenancy/project/v1/io.proto2\xc1\x04\n\x18ProjectCommandController\x12W\n\x05\x61pply\x12&.ai.stigmer.tenancy.project.v1.Project\x1a&.ai.stigmer.tenancy.project.v1.Project\x12\xa5\x01\n\x06\x63reate\x12&.ai.stigmer.tenancy.project.v1.Project\x1a&.ai.stigmer.tenancy.project.v1.Project\"K\xc2\xb8\x18G\x08\x17\x10\x1e\"\x0cmetadata.org*3unauthorized to create project in this organization\x12\x8f\x01\n\x06update\x12&.ai.stigmer.tenancy.project.v1.Project\x1a&.ai.stigmer.tenancy.project.v1.Project\"5\xc2\xb8\x18\x31\x08\x04\x10<\"\x0bmetadata.id*\x1eunauthorized to update project\x12\x8b\x01\n\x06\x64\x65lete\x12(.ai.stigmer.tenancy.project.v1.ProjectId\x1a&.ai.stigmer.tenancy.project.v1.Project\"/\xc2\xb8\x18+\x08\x02\x10<\"\x05value*\x1eunauthorized to delete project\x1a\x04\xa0\xff+<B\xca\x01\n!com.ai.stigmer.tenancy.project.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41STP\xaa\x02\x1d\x41i.Stigmer.Tenancy.Project.V1\xca\x02\x1d\x41i\\Stigmer\\Tenancy\\Project\\V1\xe2\x02)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Tenancy::Project::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.project.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.tenancy.project.v1B\014CommandProtoP\001\242\002\004ASTP\252\002\035Ai.Stigmer.Tenancy.Project.V1\312\002\035Ai\\Stigmer\\Tenancy\\Project\\V1\342\002)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\352\002!Ai::Stigmer::Tenancy::Project::V1'
  _globals['_PROJECTCOMMANDCONTROLLER']._loaded_options = None
  _globals['_PROJECTCOMMANDCONTROLLER']._serialized_options = b'\240\377+<'
  _globals['_PROJECTCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_PROJECTCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\302\270\030G\010\027\020\036\"\014metadata.org*3unauthorized to create project in this organization'
  _globals['_PROJECTCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_PROJECTCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0301\010\004\020<\"\013metadata.id*\036unauthorized to update project'
  _globals['_PROJECTCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_PROJECTCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\030+\010\002\020<\"\005value*\036unauthorized to delete project'
  _globals['_PROJECTCOMMANDCONTROLLER']._serialized_start=285
  _globals['_PROJECTCOMMANDCONTROLLER']._serialized_end=862
# @@protoc_insertion_point(module_scope)
