# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/apikey/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/apikey/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import metadata_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_metadata__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from ai.stigmer.iam.apikey.v1 import spec_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_spec__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ai/stigmer/iam/apikey/v1/api.proto\x12\x18\x61i.stigmer.iam.apikey.v1\x1a-ai/stigmer/commons/apiresource/metadata.proto\x1a+ai/stigmer/commons/apiresource/status.proto\x1a#ai/stigmer/iam/apikey/v1/spec.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb1\x02\n\x06\x41piKey\x12\x39\n\x0b\x61pi_version\x18\x01 \x01(\tB\x18\xbaH\x15r\x13\n\x11iam.stigmer.ai/v1R\napiVersion\x12!\n\x04kind\x18\x02 \x01(\tB\r\xbaH\nr\x08\n\x06\x41piKeyR\x04kind\x12O\n\x08metadata\x18\x03 \x01(\x0b\x32\x33.ai.stigmer.commons.apiresource.ApiResourceMetadataR\x08metadata\x12\x38\n\x04spec\x18\x04 \x01(\x0b\x32$.ai.stigmer.iam.apikey.v1.ApiKeySpecR\x04spec\x12>\n\x06status\x18\x05 \x01(\x0b\x32&.ai.stigmer.iam.apikey.v1.ApiKeyStatusR\x06status\"\x94\x01\n\x0c\x41piKeyStatus\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\x12<\n\x0clast_used_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nlastUsedAtB\xad\x01\n\x1c\x63om.ai.stigmer.iam.apikey.v1B\x08\x41piProtoP\x01\xa2\x02\x04\x41SIA\xaa\x02\x18\x41i.Stigmer.Iam.Apikey.V1\xca\x02\x18\x41i\\Stigmer\\Iam\\Apikey\\V1\xe2\x02$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\xea\x02\x1c\x41i::Stigmer::Iam::Apikey::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.apikey.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ai.stigmer.iam.apikey.v1B\010ApiProtoP\001\242\002\004ASIA\252\002\030Ai.Stigmer.Iam.Apikey.V1\312\002\030Ai\\Stigmer\\Iam\\Apikey\\V1\342\002$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\352\002\034Ai::Stigmer::Iam::Apikey::V1'
  _globals['_APIKEY'].fields_by_name['api_version']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['api_version']._serialized_options = b'\272H\025r\023\n\021iam.stigmer.ai/v1'
  _globals['_APIKEY'].fields_by_name['kind']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['kind']._serialized_options = b'\272H\nr\010\n\006ApiKey'
  _globals['_APIKEY']._serialized_start=256
  _globals['_APIKEY']._serialized_end=561
  _globals['_APIKEYSTATUS']._serialized_start=564
  _globals['_APIKEYSTATUS']._serialized_end=712
# @@protoc_insertion_point(module_scope)
