# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import approval_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_approval__pb2
from ai.stigmer.agentic.agentexecution.v1 import artifact_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_artifact__pb2
from ai.stigmer.agentic.agentexecution.v1 import context_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_context__pb2
from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_enum__pb2
from ai.stigmer.agentic.agentexecution.v1 import message_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_message__pb2
from ai.stigmer.agentic.agentexecution.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_spec__pb2
from ai.stigmer.agentic.agentexecution.v1 import subagent_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_subagent__pb2
from ai.stigmer.agentic.agentexecution.v1 import usage_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_usage__pb2
from ai.stigmer.commons.apiresource import metadata_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_metadata__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ai/stigmer/agentic/agentexecution/v1/api.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a\x33\x61i/stigmer/agentic/agentexecution/v1/approval.proto\x1a\x33\x61i/stigmer/agentic/agentexecution/v1/artifact.proto\x1a\x32\x61i/stigmer/agentic/agentexecution/v1/context.proto\x1a/ai/stigmer/agentic/agentexecution/v1/enum.proto\x1a\x32\x61i/stigmer/agentic/agentexecution/v1/message.proto\x1a/ai/stigmer/agentic/agentexecution/v1/spec.proto\x1a\x33\x61i/stigmer/agentic/agentexecution/v1/subagent.proto\x1a\x30\x61i/stigmer/agentic/agentexecution/v1/usage.proto\x1a-ai/stigmer/commons/apiresource/metadata.proto\x1a+ai/stigmer/commons/apiresource/status.proto\x1a\x1b\x62uf/validate/validate.proto\"\xf5\x02\n\x0e\x41gentExecution\x12=\n\x0b\x61pi_version\x18\x01 \x01(\tB\x1c\xbaH\x19r\x17\n\x15\x61gentic.stigmer.ai/v1R\napiVersion\x12)\n\x04kind\x18\x02 \x01(\tB\x15\xbaH\x12r\x10\n\x0e\x41gentExecutionR\x04kind\x12W\n\x08metadata\x18\x03 \x01(\x0b\x32\x33.ai.stigmer.commons.apiresource.ApiResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12L\n\x04spec\x18\x04 \x01(\x0b\x32\x38.ai.stigmer.agentic.agentexecution.v1.AgentExecutionSpecR\x04spec\x12R\n\x06status\x18\x05 \x01(\x0b\x32:.ai.stigmer.agentic.agentexecution.v1.AgentExecutionStatusR\x06status\"\xca\t\n\x14\x41gentExecutionStatus\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\x12N\n\x08messages\x18\x01 \x03(\x0b\x32\x32.ai.stigmer.agentic.agentexecution.v1.AgentMessageR\x08messages\x12T\n\x05phase\x18\x02 \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.ExecutionPhaseB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x05phase\x12M\n\ntool_calls\x18\x03 \x03(\x0b\x32..ai.stigmer.agentic.agentexecution.v1.ToolCallR\ttoolCalls\x12i\n\x14sub_agent_executions\x18\x04 \x03(\x0b\x32\x37.ai.stigmer.agentic.agentexecution.v1.SubAgentExecutionR\x12subAgentExecutions\x12\x14\n\x05\x65rror\x18\x06 \x01(\tR\x05\x65rror\x12\x1d\n\nstarted_at\x18\x07 \x01(\tR\tstartedAt\x12!\n\x0c\x63ompleted_at\x18\x08 \x01(\tR\x0b\x63ompletedAt\x12[\n\x05todos\x18\t \x03(\x0b\x32\x45.ai.stigmer.agentic.agentexecution.v1.AgentExecutionStatus.TodosEntryR\x05todos\x12%\n\x0e\x63\x61llback_token\x18\n \x01(\x0cR\rcallbackToken\x12H\n\x05usage\x18\x0b \x01(\x0b\x32\x32.ai.stigmer.agentic.agentexecution.v1.UsageMetricsR\x05usage\x12i\n\x10resolved_context\x18\x0c \x01(\x0b\x32>.ai.stigmer.agentic.agentexecution.v1.ResolvedExecutionContextR\x0fresolvedContext\x12\x62\n\x11pending_approvals\x18\x10 \x03(\x0b\x32\x35.ai.stigmer.agentic.agentexecution.v1.PendingApprovalR\x10pendingApprovals\x12T\n\x0c\x63ontext_info\x18\x0e \x01(\x0b\x32\x31.ai.stigmer.agentic.agentexecution.v1.ContextInfoR\x0b\x63ontextInfo\x12U\n\tartifacts\x18\x0f \x03(\x0b\x32\x37.ai.stigmer.agentic.agentexecution.v1.ExecutionArtifactR\tartifacts\x1ah\n\nTodosEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x44\n\x05value\x18\x02 \x01(\x0b\x32..ai.stigmer.agentic.agentexecution.v1.TodoItemR\x05value:\x02\x38\x01\"\xbc\x01\n\x08TodoItem\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07\x63ontent\x18\x02 \x01(\tR\x07\x63ontent\x12H\n\x06status\x18\x03 \x01(\x0e\x32\x30.ai.stigmer.agentic.agentexecution.v1.TodoStatusR\x06status\x12\x1d\n\ncreated_at\x18\x04 \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x05 \x01(\tR\tupdatedAtB\xe9\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\x08\x41piProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\010ApiProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_AGENTEXECUTION'].fields_by_name['api_version']._loaded_options = None
  _globals['_AGENTEXECUTION'].fields_by_name['api_version']._serialized_options = b'\272H\031r\027\n\025agentic.stigmer.ai/v1'
  _globals['_AGENTEXECUTION'].fields_by_name['kind']._loaded_options = None
  _globals['_AGENTEXECUTION'].fields_by_name['kind']._serialized_options = b'\272H\022r\020\n\016AgentExecution'
  _globals['_AGENTEXECUTION'].fields_by_name['metadata']._loaded_options = None
  _globals['_AGENTEXECUTION'].fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AGENTEXECUTIONSTATUS_TODOSENTRY']._loaded_options = None
  _globals['_AGENTEXECUTIONSTATUS_TODOSENTRY']._serialized_options = b'8\001'
  _globals['_AGENTEXECUTIONSTATUS'].fields_by_name['phase']._loaded_options = None
  _globals['_AGENTEXECUTIONSTATUS'].fields_by_name['phase']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_AGENTEXECUTION']._serialized_start=621
  _globals['_AGENTEXECUTION']._serialized_end=994
  _globals['_AGENTEXECUTIONSTATUS']._serialized_start=997
  _globals['_AGENTEXECUTIONSTATUS']._serialized_end=2223
  _globals['_AGENTEXECUTIONSTATUS_TODOSENTRY']._serialized_start=2119
  _globals['_AGENTEXECUTIONSTATUS_TODOSENTRY']._serialized_end=2223
  _globals['_TODOITEM']._serialized_start=2226
  _globals['_TODOITEM']._serialized_end=2414
# @@protoc_insertion_point(module_scope)
