# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/apiresourcekind/authorization_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/apiresourcekind/authorization_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIai/stigmer/commons/apiresource/apiresourcekind/authorization_config.proto\x12.ai.stigmer.commons.apiresource.apiresourcekind\";\n\x10VisibilityConfig\x12\'\n\x0fsupports_public\x18\x01 \x01(\x08R\x0esupportsPublic\"e\n\x14ParentRelationConfig\x12\x12\n\x04kind\x18\x01 \x01(\tR\x04kind\x12\x1a\n\x08relation\x18\x02 \x01(\tR\x08relation\x12\x1d\n\nspec_field\x18\x03 \x01(\tR\tspecField\"\xcc\x04\n\x13\x41uthorizationConfig\x12\x65\n\nscope_type\x18\x01 \x01(\x0e\x32\x46.ai.stigmer.commons.apiresource.apiresourcekind.AuthorizationScopeTypeR\tscopeType\x12\x63\n\nowner_type\x18\x02 \x01(\x0e\x32\x44.ai.stigmer.commons.apiresource.apiresourcekind.OwnerAttributionTypeR\townerType\x12\\\n\x06parent\x18\x03 \x01(\x0b\x32\x44.ai.stigmer.commons.apiresource.apiresourcekind.ParentRelationConfigR\x06parent\x12s\n\x12\x61\x64\x64itional_parents\x18\x04 \x03(\x0b\x32\x44.ai.stigmer.commons.apiresource.apiresourcekind.ParentRelationConfigR\x11\x61\x64\x64itionalParents\x12`\n\nvisibility\x18\x05 \x01(\x0b\x32@.ai.stigmer.commons.apiresource.apiresourcekind.VisibilityConfigR\nvisibility\x12\x34\n\x16requires_creator_tuple\x18\x06 \x01(\x08R\x14requiresCreatorTuple*\x85\x02\n\x16\x41uthorizationScopeType\x12(\n$AUTHORIZATION_SCOPE_TYPE_UNSPECIFIED\x10\x00\x12%\n!AUTHORIZATION_SCOPE_TYPE_PLATFORM\x10\x01\x12)\n%AUTHORIZATION_SCOPE_TYPE_ORGANIZATION\x10\x02\x12#\n\x1f\x41UTHORIZATION_SCOPE_TYPE_PARENT\x10\x03\x12\'\n#AUTHORIZATION_SCOPE_TYPE_OWNER_ONLY\x10\x04\x12!\n\x1d\x41UTHORIZATION_SCOPE_TYPE_NONE\x10\x05*\xc9\x01\n\x14OwnerAttributionType\x12&\n\"OWNER_ATTRIBUTION_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1dOWNER_ATTRIBUTION_TYPE_DIRECT\x10\x01\x12$\n OWNER_ATTRIBUTION_TYPE_INHERITED\x10\x02\x12\x1f\n\x1bOWNER_ATTRIBUTION_TYPE_SELF\x10\x03\x12\x1f\n\x1bOWNER_ATTRIBUTION_TYPE_NONE\x10\x04\x42\xac\x02\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\x18\x41uthorizationConfigProtoP\x01\xa2\x02\x05\x41SCAA\xaa\x02.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\xca\x02.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\xe2\x02:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\xea\x02\x32\x41i::Stigmer::Commons::Apiresource::Apiresourcekindb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.apiresourcekind.authorization_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\030AuthorizationConfigProtoP\001\242\002\005ASCAA\252\002.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\312\002.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\342\002:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\352\0022Ai::Stigmer::Commons::Apiresource::Apiresourcekind'
  _globals['_AUTHORIZATIONSCOPETYPE']._serialized_start=881
  _globals['_AUTHORIZATIONSCOPETYPE']._serialized_end=1142
  _globals['_OWNERATTRIBUTIONTYPE']._serialized_start=1145
  _globals['_OWNERATTRIBUTIONTYPE']._serialized_end=1346
  _globals['_VISIBILITYCONFIG']._serialized_start=125
  _globals['_VISIBILITYCONFIG']._serialized_end=184
  _globals['_PARENTRELATIONCONFIG']._serialized_start=186
  _globals['_PARENTRELATIONCONFIG']._serialized_end=287
  _globals['_AUTHORIZATIONCONFIG']._serialized_start=290
  _globals['_AUTHORIZATIONCONFIG']._serialized_end=878
# @@protoc_insertion_point(module_scope)
