# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/apikey/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/apikey/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.iam.apikey.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ai/stigmer/iam/apikey/v1/io.proto\x12\x18\x61i.stigmer.iam.apikey.v1\x1a\"ai/stigmer/iam/apikey/v1/api.proto\x1a\x1b\x62uf/validate/validate.proto\"E\n\x07\x41piKeys\x12:\n\x07\x65ntries\x18\x01 \x03(\x0b\x32 .ai.stigmer.iam.apikey.v1.ApiKeyR\x07\x65ntries\"(\n\x08\x41piKeyId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"*\n\nApiKeyHash\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05valueB\xac\x01\n\x1c\x63om.ai.stigmer.iam.apikey.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SIA\xaa\x02\x18\x41i.Stigmer.Iam.Apikey.V1\xca\x02\x18\x41i\\Stigmer\\Iam\\Apikey\\V1\xe2\x02$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\xea\x02\x1c\x41i::Stigmer::Iam::Apikey::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.apikey.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ai.stigmer.iam.apikey.v1B\007IoProtoP\001\242\002\004ASIA\252\002\030Ai.Stigmer.Iam.Apikey.V1\312\002\030Ai\\Stigmer\\Iam\\Apikey\\V1\342\002$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\352\002\034Ai::Stigmer::Iam::Apikey::V1'
  _globals['_APIKEYID'].fields_by_name['value']._loaded_options = None
  _globals['_APIKEYID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIKEYHASH'].fields_by_name['value']._loaded_options = None
  _globals['_APIKEYHASH'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIKEYS']._serialized_start=128
  _globals['_APIKEYS']._serialized_end=197
  _globals['_APIKEYID']._serialized_start=199
  _globals['_APIKEYID']._serialized_end=239
  _globals['_APIKEYHASH']._serialized_start=241
  _globals['_APIKEYHASH']._serialized_end=283
# @@protoc_insertion_point(module_scope)
