# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/rpc_service_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/rpc_service_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__kind__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8ai/stigmer/commons/apiresource/rpc_service_options.proto\x12\x1e\x61i.stigmer.commons.apiresource\x1a\x46\x61i/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x1a google/protobuf/descriptor.proto:\x8e\x01\n\x11\x61pi_resource_kind\x12\x1f.google.protobuf.ServiceOptions\x18\xf4\xbf\x05 \x01(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindR\x0f\x61piResourceKindB\xd8\x01\n\"com.ai.stigmer.commons.apiresourceB\x16RpcServiceOptionsProtoP\x01\xa2\x02\x04\x41SCA\xaa\x02\x1e\x41i.Stigmer.Commons.Apiresource\xca\x02\x1e\x41i\\Stigmer\\Commons\\Apiresource\xe2\x02*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\xea\x02!Ai::Stigmer::Commons::Apiresourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.rpc_service_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.commons.apiresourceB\026RpcServiceOptionsProtoP\001\242\002\004ASCA\252\002\036Ai.Stigmer.Commons.Apiresource\312\002\036Ai\\Stigmer\\Commons\\Apiresource\342\002*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\352\002!Ai::Stigmer::Commons::Apiresource'
# @@protoc_insertion_point(module_scope)
