# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/identityaccount/v1/enum.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/identityaccount/v1/enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/iam/identityaccount/v1/enum.proto\x12!ai.stigmer.iam.identityaccount.v1*}\n\x1fIdentityAccountProvisioningMode\x12\x32\n.identity_account_provisioning_mode_unspecified\x10\x00\x12\n\n\x06\x64irect\x10\x01\x12\r\n\tfederated\x10\x02\x12\x0b\n\x07machine\x10\x03\x42\xdb\x01\n%com.ai.stigmer.iam.identityaccount.v1B\tEnumProtoP\x01\xa2\x02\x04\x41SII\xaa\x02!Ai.Stigmer.Iam.Identityaccount.V1\xca\x02!Ai\\Stigmer\\Iam\\Identityaccount\\V1\xe2\x02-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Iam::Identityaccount::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.identityaccount.v1.enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.iam.identityaccount.v1B\tEnumProtoP\001\242\002\004ASII\252\002!Ai.Stigmer.Iam.Identityaccount.V1\312\002!Ai\\Stigmer\\Iam\\Identityaccount\\V1\342\002-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\352\002%Ai::Stigmer::Iam::Identityaccount::V1'
  _globals['_IDENTITYACCOUNTPROVISIONINGMODE']._serialized_start=83
  _globals['_IDENTITYACCOUNTPROVISIONINGMODE']._serialized_end=208
# @@protoc_insertion_point(module_scope)
