from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as _api_resource_kind_pb2
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
COMPUTED_FIELD_NUMBER: _ClassVar[int]
computed: _descriptor.FieldDescriptor
IMMUTABLE_FIELD_NUMBER: _ClassVar[int]
immutable: _descriptor.FieldDescriptor
IS_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
is_expression: _descriptor.FieldDescriptor
REFERENCE_KIND_FIELD_NUMBER: _ClassVar[int]
reference_kind: _descriptor.FieldDescriptor
DISCRIMINATED_BY_FIELD_NUMBER: _ClassVar[int]
discriminated_by: _descriptor.FieldDescriptor
DISCRIMINATOR_VALUE_FIELD_NUMBER: _ClassVar[int]
discriminator_value: _descriptor.FieldDescriptor
