# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ai/stigmer/commons/apiresource/status.proto\x12\x1e\x61i.stigmer.commons.apiresource\x1a\x1fgoogle/protobuf/timestamp.proto\"`\n\x16\x41piResourceAuditStatus\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\"\xc0\x01\n\x10\x41piResourceAudit\x12S\n\nspec_audit\x18\x01 \x01(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceAuditInfoR\tspecAudit\x12W\n\x0cstatus_audit\x18\x02 \x01(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceAuditInfoR\x0bstatusAudit\"\xce\x02\n\x14\x41piResourceAuditInfo\x12T\n\ncreated_by\x18\x01 \x01(\x0b\x32\x35.ai.stigmer.commons.apiresource.ApiResourceAuditActorR\tcreatedBy\x12\x39\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12T\n\nupdated_by\x18\x03 \x01(\x0b\x32\x35.ai.stigmer.commons.apiresource.ApiResourceAuditActorR\tupdatedBy\x12\x39\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x14\n\x05\x65vent\x18\x05 \x01(\tR\x05\x65vent\"?\n\x15\x41piResourceAuditActor\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06\x61vatar\x18\x02 \x01(\tR\x06\x61vatarB\xcd\x01\n\"com.ai.stigmer.commons.apiresourceB\x0bStatusProtoP\x01\xa2\x02\x04\x41SCA\xaa\x02\x1e\x41i.Stigmer.Commons.Apiresource\xca\x02\x1e\x41i\\Stigmer\\Commons\\Apiresource\xe2\x02*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\xea\x02!Ai::Stigmer::Commons::Apiresourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.commons.apiresourceB\013StatusProtoP\001\242\002\004ASCA\252\002\036Ai.Stigmer.Commons.Apiresource\312\002\036Ai\\Stigmer\\Commons\\Apiresource\342\002*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\352\002!Ai::Stigmer::Commons::Apiresource'
  _globals['_APIRESOURCEAUDITSTATUS']._serialized_start=112
  _globals['_APIRESOURCEAUDITSTATUS']._serialized_end=208
  _globals['_APIRESOURCEAUDIT']._serialized_start=211
  _globals['_APIRESOURCEAUDIT']._serialized_end=403
  _globals['_APIRESOURCEAUDITINFO']._serialized_start=406
  _globals['_APIRESOURCEAUDITINFO']._serialized_end=740
  _globals['_APIRESOURCEAUDITACTOR']._serialized_start=742
  _globals['_APIRESOURCEAUDITACTOR']._serialized_end=805
# @@protoc_insertion_point(module_scope)
