# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.executioncontext.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_executioncontext_dot_v1_dot_spec__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ai/stigmer/agentic/agentexecution/v1/spec.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a\x31\x61i/stigmer/agentic/executioncontext/v1/spec.proto\x1a\x1b\x62uf/validate/validate.proto\"\xb8\x05\n\x12\x41gentExecutionSpec\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x19\n\x08\x61gent_id\x18\x02 \x01(\tR\x07\x61gentId\x12!\n\x07message\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07message\x12`\n\x10\x65xecution_config\x18\x04 \x01(\x0b\x32\x35.ai.stigmer.agentic.agentexecution.v1.ExecutionConfigR\x0f\x65xecutionConfig\x12i\n\x0bruntime_env\x18\x05 \x03(\x0b\x32H.ai.stigmer.agentic.agentexecution.v1.AgentExecutionSpec.RuntimeEnvEntryR\nruntimeEnv\x12%\n\x0e\x63\x61llback_token\x18\x06 \x01(\x0cR\rcallbackToken\x12(\n\x10\x61uto_approve_all\x18\x07 \x01(\x08R\x0e\x61utoApproveAll\x12,\n\x12parent_workflow_id\x18\x08 \x01(\tR\x10parentWorkflowId\x12R\n\x0b\x61ttachments\x18\t \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.AttachmentR\x0b\x61ttachments\x12.\n\x13workspace_file_refs\x18\n \x03(\tR\x11workspaceFileRefs\x1au\n\x0fRuntimeEnvEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12L\n\x05value\x18\x02 \x01(\x0b\x32\x36.ai.stigmer.agentic.executioncontext.v1.ExecutionValueR\x05value:\x02\x38\x01\"\x9b\x02\n\x0f\x45xecutionConfig\x12\x1d\n\nmodel_name\x18\x01 \x01(\tR\tmodelName\x12l\n\x12\x63ontext_management\x18\x02 \x01(\x0b\x32=.ai.stigmer.agentic.agentexecution.v1.ContextManagementConfigR\x11\x63ontextManagement\x12&\n\x0fmax_tool_rounds\x18\x03 \x01(\x05R\rmaxToolRounds\x12\x31\n\x15max_tool_result_chars\x18\x04 \x01(\x05R\x12maxToolResultChars\x12 \n\x0cmax_cost_usd\x18\x05 \x01(\x01R\nmaxCostUsd\"\xcc\x01\n\x17\x43ontextManagementConfig\x12\x33\n\x15\x64isable_summarization\x18\x01 \x01(\x08R\x14\x64isableSummarization\x12\x41\n\x18\x63ustom_trigger_threshold\x18\x02 \x01(\x05\x42\x07\xbaH\x04\x1a\x02(\x00R\x16\x63ustomTriggerThreshold\x12\x39\n\x14\x63ustom_target_tokens\x18\x03 \x01(\x05\x42\x07\xbaH\x04\x1a\x02(\x00R\x12\x63ustomTargetTokens\"\xd6\x01\n\nAttachment\x12#\n\x08\x66ilename\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08\x66ilename\x12(\n\x0bstorage_key\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nstorageKey\x12\x1d\n\nmount_path\x18\x03 \x01(\tR\tmountPath\x12!\n\x0c\x63ontent_type\x18\x04 \x01(\tR\x0b\x63ontentType\x12\x18\n\x07\x65xtract\x18\x05 \x01(\x08R\x07\x65xtract\x12\x1d\n\nlocal_path\x18\x06 \x01(\tR\tlocalPathB\xea\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\tSpecProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_AGENTEXECUTIONSPEC_RUNTIMEENVENTRY']._loaded_options = None
  _globals['_AGENTEXECUTIONSPEC_RUNTIMEENVENTRY']._serialized_options = b'8\001'
  _globals['_AGENTEXECUTIONSPEC'].fields_by_name['message']._loaded_options = None
  _globals['_AGENTEXECUTIONSPEC'].fields_by_name['message']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_CONTEXTMANAGEMENTCONFIG'].fields_by_name['custom_trigger_threshold']._loaded_options = None
  _globals['_CONTEXTMANAGEMENTCONFIG'].fields_by_name['custom_trigger_threshold']._serialized_options = b'\272H\004\032\002(\000'
  _globals['_CONTEXTMANAGEMENTCONFIG'].fields_by_name['custom_target_tokens']._loaded_options = None
  _globals['_CONTEXTMANAGEMENTCONFIG'].fields_by_name['custom_target_tokens']._serialized_options = b'\272H\004\032\002(\000'
  _globals['_ATTACHMENT'].fields_by_name['filename']._loaded_options = None
  _globals['_ATTACHMENT'].fields_by_name['filename']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ATTACHMENT'].fields_by_name['storage_key']._loaded_options = None
  _globals['_ATTACHMENT'].fields_by_name['storage_key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_AGENTEXECUTIONSPEC']._serialized_start=170
  _globals['_AGENTEXECUTIONSPEC']._serialized_end=866
  _globals['_AGENTEXECUTIONSPEC_RUNTIMEENVENTRY']._serialized_start=749
  _globals['_AGENTEXECUTIONSPEC_RUNTIMEENVENTRY']._serialized_end=866
  _globals['_EXECUTIONCONFIG']._serialized_start=869
  _globals['_EXECUTIONCONFIG']._serialized_end=1152
  _globals['_CONTEXTMANAGEMENTCONFIG']._serialized_start=1155
  _globals['_CONTEXTMANAGEMENTCONFIG']._serialized_end=1359
  _globals['_ATTACHMENT']._serialized_start=1362
  _globals['_ATTACHMENT']._serialized_end=1576
# @@protoc_insertion_point(module_scope)
