# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/context.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/context.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_enum__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/stigmer/agentic/agentexecution/v1/context.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a/ai/stigmer/agentic/agentexecution/v1/enum.proto\"\x89\x03\n\x18ResolvedExecutionContext\x12)\n\x10\x65nvironment_keys\x18\x01 \x03(\tR\x0f\x65nvironmentKeys\x12o\n\x0bmcp_servers\x18\x02 \x03(\x0b\x32N.ai.stigmer.agentic.agentexecution.v1.ResolvedExecutionContext.McpServersEntryR\nmcpServers\x12\x1f\n\x0bskill_names\x18\x03 \x03(\tR\nskillNames\x12\x30\n\x14\x65xcluded_skill_names\x18\x04 \x03(\tR\x12\x65xcludedSkillNames\x1a~\n\x0fMcpServersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12U\n\x05value\x18\x02 \x01(\x0b\x32?.ai.stigmer.agentic.agentexecution.v1.McpServerResolutionStatusR\x05value:\x02\x38\x01\"\x7f\n\x19McpServerResolutionStatus\x12\x1a\n\x08resolved\x18\x01 \x01(\x08R\x08resolved\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12,\n\x12\x65nabled_tool_count\x18\x03 \x01(\x05R\x10\x65nabledToolCount\"\xd0\x04\n\x12SummarizationEvent\x12\x1c\n\ttimestamp\x18\x01 \x01(\tR\ttimestamp\x12#\n\rtokens_before\x18\x02 \x01(\x05R\x0ctokensBefore\x12!\n\x0ctokens_after\x18\x03 \x01(\x05R\x0btokensAfter\x12+\n\x11\x63ompression_ratio\x18\x04 \x01(\x02R\x10\x63ompressionRatio\x12\x1f\n\x0b\x64uration_ms\x18\x05 \x01(\x05R\ndurationMs\x12/\n\x13summarization_model\x18\x06 \x01(\tR\x12summarizationModel\x12\'\n\x0fmessages_before\x18\x07 \x01(\x05R\x0emessagesBefore\x12%\n\x0emessages_after\x18\x08 \x01(\x05R\rmessagesAfter\x12Q\n\x06source\x18\t \x01(\x0e\x32\x39.ai.stigmer.agentic.agentexecution.v1.SummarizationSourceR\x06source\x12<\n\x1asummarization_input_tokens\x18\n \x01(\x05R\x18summarizationInputTokens\x12>\n\x1bsummarization_output_tokens\x18\x0b \x01(\x05R\x19summarizationOutputTokens\x12\x34\n\x16summarization_cost_usd\x18\x0c \x01(\x01R\x14summarizationCostUsd\"\xca\x03\n\x0b\x43ontextInfo\x12.\n\x13\x63urrent_token_count\x18\x01 \x01(\x05R\x11\x63urrentTokenCount\x12\x30\n\x14\x63ontext_window_limit\x18\x02 \x01(\x05R\x12\x63ontextWindowLimit\x12\x46\n\x1fsummarization_trigger_threshold\x18\x03 \x01(\x05R\x1dsummarizationTriggerThreshold\x12>\n\x1bsummarization_target_tokens\x18\x04 \x01(\x05R\x19summarizationTargetTokens\x12\x33\n\x15summarization_enabled\x18\x05 \x01(\x08R\x14summarizationEnabled\x12k\n\x14summarization_events\x18\x06 \x03(\x0b\x32\x38.ai.stigmer.agentic.agentexecution.v1.SummarizationEventR\x13summarizationEvents\x12/\n\x13utilization_percent\x18\x07 \x01(\x02R\x12utilizationPercentB\xed\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\x0c\x43ontextProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.context_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\014ContextProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_RESOLVEDEXECUTIONCONTEXT_MCPSERVERSENTRY']._loaded_options = None
  _globals['_RESOLVEDEXECUTIONCONTEXT_MCPSERVERSENTRY']._serialized_options = b'8\001'
  _globals['_RESOLVEDEXECUTIONCONTEXT']._serialized_start=142
  _globals['_RESOLVEDEXECUTIONCONTEXT']._serialized_end=535
  _globals['_RESOLVEDEXECUTIONCONTEXT_MCPSERVERSENTRY']._serialized_start=409
  _globals['_RESOLVEDEXECUTIONCONTEXT_MCPSERVERSENTRY']._serialized_end=535
  _globals['_MCPSERVERRESOLUTIONSTATUS']._serialized_start=537
  _globals['_MCPSERVERRESOLUTIONSTATUS']._serialized_end=664
  _globals['_SUMMARIZATIONEVENT']._serialized_start=667
  _globals['_SUMMARIZATIONEVENT']._serialized_end=1259
  _globals['_CONTEXTINFO']._serialized_start=1262
  _globals['_CONTEXTINFO']._serialized_end=1720
# @@protoc_insertion_point(module_scope)
