# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowinstance/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowinstance/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflowinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowinstance.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/stigmer/agentic/workflowinstance/v1/query.proto\x12&ai.stigmer.agentic.workflowinstance.v1\x1a\x30\x61i/stigmer/agentic/workflowinstance/v1/api.proto\x1a/ai/stigmer/agentic/workflowinstance/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\x8b\x04\n\x1fWorkflowInstanceQueryController\x12\xb3\x01\n\x03get\x12:.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceId\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"6\xc2\xb8\x18\x32\x08\x03\x10\x33\"\x05value*%unauthorized to get workflow instance\x12\xa2\x01\n\rgetByWorkflow\x12M.ai.stigmer.agentic.workflowinstance.v1.GetWorkflowInstancesByWorkflowRequest\x1a<.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceList\"\x04\xd0\xb8\x18\x01\x12\x86\x01\n\x0egetByReference\x12\x34.ai.stigmer.commons.apiresource.ApiResourceReference\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+3B\xf5\x01\n*com.ai.stigmer.agentic.workflowinstance.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02&Ai.Stigmer.Agentic.Workflowinstance.V1\xca\x02&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\xe2\x02\x32\x41i\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\xea\x02*Ai::Stigmer::Agentic::Workflowinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowinstance.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.ai.stigmer.agentic.workflowinstance.v1B\nQueryProtoP\001\242\002\004ASAW\252\002&Ai.Stigmer.Agentic.Workflowinstance.V1\312\002&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\342\0022Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\352\002*Ai::Stigmer::Agentic::Workflowinstance::V1'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER']._loaded_options = None
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER']._serialized_options = b'\240\377+3'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\0302\010\003\0203\"\005value*%unauthorized to get workflow instance'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['getByWorkflow']._loaded_options = None
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['getByWorkflow']._serialized_options = b'\320\270\030\001'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['getByReference']._loaded_options = None
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['getByReference']._serialized_options = b'\320\270\030\001'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER']._serialized_start=360
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER']._serialized_end=883
# @@protoc_insertion_point(module_scope)
