# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/search/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/search/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__kind__pb2
from ai.stigmer.commons.apiresource import enum_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_enum__pb2
from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61i/stigmer/search/v1/io.proto\x12\x14\x61i.stigmer.search.v1\x1a\x46\x61i/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x1a)ai/stigmer/commons/apiresource/enum.proto\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x02\n\rSearchRequest\x12\x64\n\x05kinds\x18\x01 \x03(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindB\r\xbaH\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01R\x05kinds\x12\x1e\n\x05query\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03R\x05query\x12/\n\x03org\x18\x03 \x01(\tB\x1d\xbaH\x1ar\x18\x18?2\x14^$|^[a-z][a-z0-9-]*$R\x03org\x12%\n\x0e\x65xclude_public\x18\x04 \x01(\x08R\rexcludePublic\x12\x34\n\x04page\x18\x05 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x04page\"\xaf\x02\n\x0eSearchResponse\x12<\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\".ai.stigmer.search.v1.SearchResultR\x07\x65ntries\x12\\\n\x0e\x63ounts_by_kind\x18\x02 \x03(\x0b\x32\x36.ai.stigmer.search.v1.SearchResponse.CountsByKindEntryR\x0c\x63ountsByKind\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCount\x12\x1f\n\x0btotal_pages\x18\x04 \x01(\x05R\ntotalPages\x1a?\n\x11\x43ountsByKindEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"\xed\x03\n\x0cSearchResult\x12S\n\x04kind\x18\x01 \x01(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindR\x04kind\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x04 \x01(\tR\x04slug\x12%\n\x0equalified_slug\x18\x05 \x01(\tR\rqualifiedSlug\x12\x10\n\x03org\x18\x06 \x01(\tR\x03org\x12 \n\x0b\x64\x65scription\x18\x07 \x01(\tR\x0b\x64\x65scription\x12U\n\nvisibility\x18\x08 \x01(\x0e\x32\x35.ai.stigmer.commons.apiresource.ApiResourceVisibilityR\nvisibility\x12\x12\n\x04tags\x18\t \x03(\tR\x04tags\x12\x39\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x14\n\x05score\x18\x0c \x01(\x02R\x05scoreB\x96\x01\n\x18\x63om.ai.stigmer.search.v1B\x07IoProtoP\x01\xa2\x02\x03\x41SS\xaa\x02\x14\x41i.Stigmer.Search.V1\xca\x02\x14\x41i\\Stigmer\\Search\\V1\xe2\x02 Ai\\Stigmer\\Search\\V1\\GPBMetadata\xea\x02\x17\x41i::Stigmer::Search::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.search.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.ai.stigmer.search.v1B\007IoProtoP\001\242\002\003ASS\252\002\024Ai.Stigmer.Search.V1\312\002\024Ai\\Stigmer\\Search\\V1\342\002 Ai\\Stigmer\\Search\\V1\\GPBMetadata\352\002\027Ai::Stigmer::Search::V1'
  _globals['_SEARCHREQUEST'].fields_by_name['kinds']._loaded_options = None
  _globals['_SEARCHREQUEST'].fields_by_name['kinds']._serialized_options = b'\272H\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_SEARCHREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_SEARCHREQUEST'].fields_by_name['query']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_SEARCHREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_SEARCHREQUEST'].fields_by_name['org']._serialized_options = b'\272H\032r\030\030?2\024^$|^[a-z][a-z0-9-]*$'
  _globals['_SEARCHRESPONSE_COUNTSBYKINDENTRY']._loaded_options = None
  _globals['_SEARCHRESPONSE_COUNTSBYKINDENTRY']._serialized_options = b'8\001'
  _globals['_SEARCHREQUEST']._serialized_start=274
  _globals['_SEARCHREQUEST']._serialized_end=565
  _globals['_SEARCHRESPONSE']._serialized_start=568
  _globals['_SEARCHRESPONSE']._serialized_end=871
  _globals['_SEARCHRESPONSE_COUNTSBYKINDENTRY']._serialized_start=808
  _globals['_SEARCHRESPONSE_COUNTSBYKINDENTRY']._serialized_end=871
  _globals['_SEARCHRESULT']._serialized_start=874
  _globals['_SEARCHRESULT']._serialized_end=1367
# @@protoc_insertion_point(module_scope)
