# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/approval.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/approval.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3ai/stigmer/agentic/agentexecution/v1/approval.proto\x12$ai.stigmer.agentic.agentexecution.v1\"\xd8\x02\n\x0fPendingApproval\x12 \n\x0ctool_call_id\x18\x01 \x01(\tR\ntoolCallId\x12\x1b\n\ttool_name\x18\x02 \x01(\tR\x08toolName\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12!\n\x0c\x61rgs_preview\x18\x04 \x01(\tR\x0b\x61rgsPreview\x12!\n\x0crequested_at\x18\x05 \x01(\tR\x0brequestedAt\x12$\n\x0e\x66rom_sub_agent\x18\x06 \x01(\x08R\x0c\x66romSubAgent\x12$\n\x0esub_agent_name\x18\x07 \x01(\tR\x0csubAgentName\x12\x37\n\x18\x63hild_agent_execution_id\x18\x08 \x01(\tR\x15\x63hildAgentExecutionId\x12!\n\x0cinterrupt_id\x18\t \x01(\tR\x0binterruptId\"\xa2\x01\n\x19\x43hildApprovalNotification\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x62\n\x11pending_approvals\x18\x02 \x03(\x0b\x32\x35.ai.stigmer.agentic.agentexecution.v1.PendingApprovalR\x10pendingApprovalsB\xee\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\rApprovalProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.approval_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\rApprovalProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_PENDINGAPPROVAL']._serialized_start=94
  _globals['_PENDINGAPPROVAL']._serialized_end=438
  _globals['_CHILDAPPROVALNOTIFICATION']._serialized_start=441
  _globals['_CHILDAPPROVALNOTIFICATION']._serialized_end=603
# @@protoc_insertion_point(module_scope)
