# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/skill/v1/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/skill/v1/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/stigmer/agentic/skill/v1/status.proto\x12\x1b\x61i.stigmer.agentic.skill.v1\x1a+ai/stigmer/commons/apiresource/status.proto\x1a\x1b\x62uf/validate/validate.proto\"\xd3\x02\n\x0bSkillStatus\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\x12\x38\n\x0cversion_hash\x18\x01 \x01(\tB\x15\xbaH\x12r\x10\x32\x0e^[a-f0-9]{64}$R\x0bversionHash\x12\x30\n\x14\x61rtifact_storage_key\x18\x02 \x01(\tR\x12\x61rtifactStorageKey\x12=\n\x05state\x18\x03 \x01(\x0e\x32\'.ai.stigmer.agentic.skill.v1.SkillStateR\x05state\x12Q\n\x0egit_provenance\x18\x04 \x01(\x0b\x32*.ai.stigmer.agentic.skill.v1.GitProvenanceR\rgitProvenance\"\x82\x01\n\rGitProvenance\x12&\n\nremote_url\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\tremoteUrl\x12\x10\n\x03ref\x18\x02 \x01(\tR\x03ref\x12\x1f\n\x06\x63ommit\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06\x63ommit\x12\x16\n\x06subdir\x18\x04 \x01(\tR\x06subdir*s\n\nSkillState\x12\x1b\n\x17SKILL_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15SKILL_STATE_UPLOADING\x10\x01\x12\x15\n\x11SKILL_STATE_READY\x10\x02\x12\x16\n\x12SKILL_STATE_FAILED\x10\x03\x42\xbf\x01\n\x1f\x63om.ai.stigmer.agentic.skill.v1B\x0bStatusProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1b\x41i.Stigmer.Agentic.Skill.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Skill\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Skill::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.skill.v1.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.skill.v1B\013StatusProtoP\001\242\002\004ASAS\252\002\033Ai.Stigmer.Agentic.Skill.V1\312\002\033Ai\\Stigmer\\Agentic\\Skill\\V1\342\002\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Skill::V1'
  _globals['_SKILLSTATUS'].fields_by_name['version_hash']._loaded_options = None
  _globals['_SKILLSTATUS'].fields_by_name['version_hash']._serialized_options = b'\272H\022r\0202\016^[a-f0-9]{64}$'
  _globals['_GITPROVENANCE'].fields_by_name['remote_url']._loaded_options = None
  _globals['_GITPROVENANCE'].fields_by_name['remote_url']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GITPROVENANCE'].fields_by_name['commit']._loaded_options = None
  _globals['_GITPROVENANCE'].fields_by_name['commit']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SKILLSTATE']._serialized_start=622
  _globals['_SKILLSTATE']._serialized_end=737
  _globals['_SKILLSTATUS']._serialized_start=148
  _globals['_SKILLSTATUS']._serialized_end=487
  _globals['_GITPROVENANCE']._serialized_start=490
  _globals['_GITPROVENANCE']._serialized_end=620
# @@protoc_insertion_point(module_scope)
