# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowinstance/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowinstance/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflowinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowinstance.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ai/stigmer/agentic/workflowinstance/v1/command.proto\x12&ai.stigmer.agentic.workflowinstance.v1\x1a\x30\x61i/stigmer/agentic/workflowinstance/v1/api.proto\x1a/ai/stigmer/agentic/workflowinstance/v1/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xa7\x05\n!WorkflowInstanceCommandController\x12{\n\x05\x61pply\x12\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\x12\x82\x01\n\x06\x63reate\x12\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"\x04\xd0\xb8\x18\x01\x12\xbd\x01\n\x06update\x12\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"?\xc2\xb8\x18;\x08\x04\x10\x33\"\x0bmetadata.id*(unauthorized to update workflow instance\x12\xb9\x01\n\x06\x64\x65lete\x12:.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceId\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"9\xc2\xb8\x18\x35\x08\x02\x10\x33\"\x05value*(unauthorized to delete workflow instance\x1a\x04\xa0\xff+3B\xf7\x01\n*com.ai.stigmer.agentic.workflowinstance.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02&Ai.Stigmer.Agentic.Workflowinstance.V1\xca\x02&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\xe2\x02\x32\x41i\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\xea\x02*Ai::Stigmer::Agentic::Workflowinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowinstance.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.ai.stigmer.agentic.workflowinstance.v1B\014CommandProtoP\001\242\002\004ASAW\252\002&Ai.Stigmer.Agentic.Workflowinstance.V1\312\002&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\342\0022Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\352\002*Ai::Stigmer::Agentic::Workflowinstance::V1'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER']._loaded_options = None
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER']._serialized_options = b'\240\377+3'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\320\270\030\001'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\030;\010\004\0203\"\013metadata.id*(unauthorized to update workflow instance'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\0305\010\002\0203\"\005value*(unauthorized to delete workflow instance'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER']._serialized_start=321
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER']._serialized_end=1000
# @@protoc_insertion_point(module_scope)
