# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowexecution/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowexecution/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_enum__pb2
from ai.stigmer.agentic.workflowexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_enum__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/stigmer/agentic/workflowexecution/v1/io.proto\x12\'ai.stigmer.agentic.workflowexecution.v1\x1a/ai/stigmer/agentic/agentexecution/v1/enum.proto\x1a\x31\x61i/stigmer/agentic/workflowexecution/v1/api.proto\x1a\x32\x61i/stigmer/agentic/workflowexecution/v1/enum.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/protobuf/struct.proto\"3\n\x13WorkflowExecutionId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"*\n\nWorkflowId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x8e\x01\n\x15WorkflowExecutionList\x12\x1f\n\x0btotal_pages\x18\x01 \x01(\x05R\ntotalPages\x12T\n\x07\x65ntries\x18\x02 \x03(\x0b\x32:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionR\x07\x65ntries\"\xbe\x01\n\x1dListWorkflowExecutionsRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12M\n\x05phase\x18\x03 \x01(\x0e\x32\x37.ai.stigmer.agentic.workflowexecution.v1.ExecutionPhaseR\x05phase\x12\x12\n\x04tags\x18\x04 \x03(\tR\x04tags\"\x8e\x01\n\'ListWorkflowExecutionsByWorkflowRequest\x12\'\n\x0bworkflow_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\nworkflowId\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xb2\x01\n\"WorkflowExecutionUpdateStatusInput\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12`\n\x06status\x18\x02 \x01(\x0b\x32@.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionStatusB\x06\xbaH\x03\xc8\x01\x01R\x06status\"\xe8\x01\n\x1bSubmitWorkflowApprovalInput\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12)\n\x0ctool_call_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\ntoolCallId\x12X\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.ApprovalActionB\n\xbaH\x07\x82\x01\x04\x10\x01 \x00R\x06\x61\x63tion\x12\x18\n\x07\x63omment\x18\x04 \x01(\tR\x07\x63omment\"N\n!SubscribeWorkflowExecutionRequest\x12)\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0b\x65xecutionId\"\xa6\x02\n\x17WorkflowExecutionUpdate\x12\x66\n\x0bupdate_type\x18\x01 \x01(\x0e\x32;.ai.stigmer.agentic.workflowexecution.v1.WorkflowUpdateTypeB\x08\xbaH\x05\x82\x01\x02\x10\x01R\nupdateType\x12X\n\texecution\x18\x02 \x01(\x0b\x32:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionR\texecution\x12I\n\x04task\x18\x03 \x01(\x0b\x32\x35.ai.stigmer.agentic.workflowexecution.v1.WorkflowTaskR\x04task\"O\n\x1c\x43\x61ncelWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"R\n\x1fTerminateWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"P\n\x1dRecoverWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"N\n\x1bPauseWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"7\n\x1cResumeWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\"\xc3\x01\n\x0fSendSignalInput\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12(\n\x0bsignal_name\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nsignalName\x12\x31\n\x07payload\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07payload\x12\'\n\x0fidempotency_key\x18\x04 \x01(\tR\x0eidempotencyKey*\xf3\x01\n\x12WorkflowUpdateType\x12$\n workflow_update_type_unspecified\x10\x00\x12\x1c\n\x18wf_update_status_changed\x10\x01\x12\x1a\n\x16wf_update_task_started\x10\x02\x12\x1c\n\x18wf_update_task_completed\x10\x03\x12\x19\n\x15wf_update_task_failed\x10\x04\x12!\n\x1dwf_update_execution_completed\x10\x05\x12!\n\x1dwf_update_execution_cancelled\x10\x06\x42\xf7\x01\n+com.ai.stigmer.agentic.workflowexecution.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\'Ai.Stigmer.Agentic.Workflowexecution.V1\xca\x02\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\xe2\x02\x33\x41i\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\xea\x02+Ai::Stigmer::Agentic::Workflowexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowexecution.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.ai.stigmer.agentic.workflowexecution.v1B\007IoProtoP\001\242\002\004ASAW\252\002\'Ai.Stigmer.Agentic.Workflowexecution.V1\312\002\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\342\0023Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\352\002+Ai::Stigmer::Agentic::Workflowexecution::V1'
  _globals['_WORKFLOWEXECUTIONID'].fields_by_name['value']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWID'].fields_by_name['value']._loaded_options = None
  _globals['_WORKFLOWID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTWORKFLOWEXECUTIONSBYWORKFLOWREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_LISTWORKFLOWEXECUTIONSBYWORKFLOWREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT'].fields_by_name['execution_id']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT'].fields_by_name['status']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT'].fields_by_name['status']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['execution_id']._loaded_options = None
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['tool_call_id']._loaded_options = None
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['tool_call_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['action']._loaded_options = None
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['action']._serialized_options = b'\272H\007\202\001\004\020\001 \000'
  _globals['_SUBSCRIBEWORKFLOWEXECUTIONREQUEST'].fields_by_name['execution_id']._loaded_options = None
  _globals['_SUBSCRIBEWORKFLOWEXECUTIONREQUEST'].fields_by_name['execution_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWEXECUTIONUPDATE'].fields_by_name['update_type']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONUPDATE'].fields_by_name['update_type']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_CANCELWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_CANCELWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_TERMINATEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_TERMINATEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RECOVERWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_RECOVERWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PAUSEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_PAUSEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RESUMEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_RESUMEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SENDSIGNALINPUT'].fields_by_name['execution_id']._loaded_options = None
  _globals['_SENDSIGNALINPUT'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SENDSIGNALINPUT'].fields_by_name['signal_name']._loaded_options = None
  _globals['_SENDSIGNALINPUT'].fields_by_name['signal_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WORKFLOWUPDATETYPE']._serialized_start=2260
  _globals['_WORKFLOWUPDATETYPE']._serialized_end=2503
  _globals['_WORKFLOWEXECUTIONID']._serialized_start=304
  _globals['_WORKFLOWEXECUTIONID']._serialized_end=355
  _globals['_WORKFLOWID']._serialized_start=357
  _globals['_WORKFLOWID']._serialized_end=399
  _globals['_WORKFLOWEXECUTIONLIST']._serialized_start=402
  _globals['_WORKFLOWEXECUTIONLIST']._serialized_end=544
  _globals['_LISTWORKFLOWEXECUTIONSREQUEST']._serialized_start=547
  _globals['_LISTWORKFLOWEXECUTIONSREQUEST']._serialized_end=737
  _globals['_LISTWORKFLOWEXECUTIONSBYWORKFLOWREQUEST']._serialized_start=740
  _globals['_LISTWORKFLOWEXECUTIONSBYWORKFLOWREQUEST']._serialized_end=882
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT']._serialized_start=885
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT']._serialized_end=1063
  _globals['_SUBMITWORKFLOWAPPROVALINPUT']._serialized_start=1066
  _globals['_SUBMITWORKFLOWAPPROVALINPUT']._serialized_end=1298
  _globals['_SUBSCRIBEWORKFLOWEXECUTIONREQUEST']._serialized_start=1300
  _globals['_SUBSCRIBEWORKFLOWEXECUTIONREQUEST']._serialized_end=1378
  _globals['_WORKFLOWEXECUTIONUPDATE']._serialized_start=1381
  _globals['_WORKFLOWEXECUTIONUPDATE']._serialized_end=1675
  _globals['_CANCELWORKFLOWEXECUTIONINPUT']._serialized_start=1677
  _globals['_CANCELWORKFLOWEXECUTIONINPUT']._serialized_end=1756
  _globals['_TERMINATEWORKFLOWEXECUTIONINPUT']._serialized_start=1758
  _globals['_TERMINATEWORKFLOWEXECUTIONINPUT']._serialized_end=1840
  _globals['_RECOVERWORKFLOWEXECUTIONINPUT']._serialized_start=1842
  _globals['_RECOVERWORKFLOWEXECUTIONINPUT']._serialized_end=1922
  _globals['_PAUSEWORKFLOWEXECUTIONINPUT']._serialized_start=1924
  _globals['_PAUSEWORKFLOWEXECUTIONINPUT']._serialized_end=2002
  _globals['_RESUMEWORKFLOWEXECUTIONINPUT']._serialized_start=2004
  _globals['_RESUMEWORKFLOWEXECUTIONINPUT']._serialized_end=2059
  _globals['_SENDSIGNALINPUT']._serialized_start=2062
  _globals['_SENDSIGNALINPUT']._serialized_end=2257
# @@protoc_insertion_point(module_scope)
