# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ai/stigmer/iam/iampolicy/v1/spec.proto\x12\x1b\x61i.stigmer.iam.iampolicy.v1\x1a\x1b\x62uf/validate/validate.proto\"\xdd\x01\n\rIamPolicySpec\x12Q\n\tprincipal\x18\x01 \x01(\x0b\x32+.ai.stigmer.iam.iampolicy.v1.ApiResourceRefB\x06\xbaH\x03\xc8\x01\x01R\tprincipal\x12O\n\x08resource\x18\x02 \x01(\x0b\x32+.ai.stigmer.iam.iampolicy.v1.ApiResourceRefB\x06\xbaH\x03\xc8\x01\x01R\x08resource\x12(\n\x08relation\x18\x03 \x01(\tB\x0c\xbaH\tr\x04\x10\x01\x18@\xc8\x01\x01R\x08relation\"x\n\x0e\x41piResourceRef\x12!\n\x04kind\x18\x01 \x01(\tB\r\xbaH\nr\x05\x10\x01\x18\x80\x02\xc8\x01\x01R\x04kind\x12\x1d\n\x02id\x18\x02 \x01(\tB\r\xbaH\nr\x05\x10\x01\x18\x80\x02\xc8\x01\x01R\x02id\x12$\n\x08relation\x18\x03 \x01(\tB\x08\xbaH\x05r\x03\x18\x80\x02R\x08relationB\xbd\x01\n\x1f\x63om.ai.stigmer.iam.iampolicy.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SII\xaa\x02\x1b\x41i.Stigmer.Iam.Iampolicy.V1\xca\x02\x1b\x41i\\Stigmer\\Iam\\Iampolicy\\V1\xe2\x02\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Iam::Iampolicy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.iam.iampolicy.v1B\tSpecProtoP\001\242\002\004ASII\252\002\033Ai.Stigmer.Iam.Iampolicy.V1\312\002\033Ai\\Stigmer\\Iam\\Iampolicy\\V1\342\002\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Iam::Iampolicy::V1'
  _globals['_IAMPOLICYSPEC'].fields_by_name['principal']._loaded_options = None
  _globals['_IAMPOLICYSPEC'].fields_by_name['principal']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IAMPOLICYSPEC'].fields_by_name['resource']._loaded_options = None
  _globals['_IAMPOLICYSPEC'].fields_by_name['resource']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IAMPOLICYSPEC'].fields_by_name['relation']._loaded_options = None
  _globals['_IAMPOLICYSPEC'].fields_by_name['relation']._serialized_options = b'\272H\tr\004\020\001\030@\310\001\001'
  _globals['_APIRESOURCEREF'].fields_by_name['kind']._loaded_options = None
  _globals['_APIRESOURCEREF'].fields_by_name['kind']._serialized_options = b'\272H\nr\005\020\001\030\200\002\310\001\001'
  _globals['_APIRESOURCEREF'].fields_by_name['id']._loaded_options = None
  _globals['_APIRESOURCEREF'].fields_by_name['id']._serialized_options = b'\272H\nr\005\020\001\030\200\002\310\001\001'
  _globals['_APIRESOURCEREF'].fields_by_name['relation']._loaded_options = None
  _globals['_APIRESOURCEREF'].fields_by_name['relation']._serialized_options = b'\272H\005r\003\030\200\002'
  _globals['_IAMPOLICYSPEC']._serialized_start=101
  _globals['_IAMPOLICYSPEC']._serialized_end=322
  _globals['_APIRESOURCEREF']._serialized_start=324
  _globals['_APIRESOURCEREF']._serialized_end=444
# @@protoc_insertion_point(module_scope)
