# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowexecution/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowexecution/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import approval_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_approval__pb2
from ai.stigmer.agentic.workflowexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_enum__pb2
from ai.stigmer.agentic.workflowexecution.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_spec__pb2
from ai.stigmer.commons.apiresource import metadata_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_metadata__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ai/stigmer/agentic/workflowexecution/v1/api.proto\x12\'ai.stigmer.agentic.workflowexecution.v1\x1a\x33\x61i/stigmer/agentic/agentexecution/v1/approval.proto\x1a\x32\x61i/stigmer/agentic/workflowexecution/v1/enum.proto\x1a\x32\x61i/stigmer/agentic/workflowexecution/v1/spec.proto\x1a-ai/stigmer/commons/apiresource/metadata.proto\x1a+ai/stigmer/commons/apiresource/status.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x87\x03\n\x11WorkflowExecution\x12=\n\x0b\x61pi_version\x18\x01 \x01(\tB\x1c\xbaH\x19r\x17\n\x15\x61gentic.stigmer.ai/v1R\napiVersion\x12,\n\x04kind\x18\x02 \x01(\tB\x18\xbaH\x15r\x13\n\x11WorkflowExecutionR\x04kind\x12W\n\x08metadata\x18\x03 \x01(\x0b\x32\x33.ai.stigmer.commons.apiresource.ApiResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12R\n\x04spec\x18\x04 \x01(\x0b\x32>.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionSpecR\x04spec\x12X\n\x06status\x18\x05 \x01(\x0b\x32@.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionStatusR\x06status\"\xa6\x04\n\x17WorkflowExecutionStatus\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\x12W\n\x05phase\x18\x01 \x01(\x0e\x32\x37.ai.stigmer.agentic.workflowexecution.v1.ExecutionPhaseB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x05phase\x12K\n\x05tasks\x18\x02 \x03(\x0b\x32\x35.ai.stigmer.agentic.workflowexecution.v1.WorkflowTaskR\x05tasks\x12/\n\x06output\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x06output\x12\x14\n\x05\x65rror\x18\x04 \x01(\tR\x05\x65rror\x12\x1d\n\nstarted_at\x18\x05 \x01(\tR\tstartedAt\x12!\n\x0c\x63ompleted_at\x18\x06 \x01(\tR\x0b\x63ompletedAt\x12\x30\n\x14temporal_workflow_id\x18\x07 \x01(\tR\x12temporalWorkflowId\x12\x62\n\x11pending_approvals\x18\t \x03(\x0b\x32\x35.ai.stigmer.agentic.agentexecution.v1.PendingApprovalR\x10pendingApprovals\"\xf2\x03\n\x0cWorkflowTask\x12\x17\n\x07task_id\x18\x01 \x01(\tR\x06taskId\x12\x1b\n\ttask_name\x18\x02 \x01(\tR\x08taskName\x12`\n\ttask_type\x18\x03 \x01(\x0e\x32\x39.ai.stigmer.agentic.workflowexecution.v1.WorkflowTaskTypeB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x08taskType\x12-\n\x05input\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x05input\x12/\n\x06output\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x06output\x12]\n\x06status\x18\x06 \x01(\x0e\x32;.ai.stigmer.agentic.workflowexecution.v1.WorkflowTaskStatusB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x06status\x12\x1d\n\nstarted_at\x18\x07 \x01(\tR\tstartedAt\x12!\n\x0c\x63ompleted_at\x18\x08 \x01(\tR\x0b\x63ompletedAt\x12\x14\n\x05\x65rror\x18\t \x01(\tR\x05\x65rror\x12\x33\n\x08metadata\x18\n \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadataB\xf8\x01\n+com.ai.stigmer.agentic.workflowexecution.v1B\x08\x41piProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\'Ai.Stigmer.Agentic.Workflowexecution.V1\xca\x02\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\xe2\x02\x33\x41i\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\xea\x02+Ai::Stigmer::Agentic::Workflowexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowexecution.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.ai.stigmer.agentic.workflowexecution.v1B\010ApiProtoP\001\242\002\004ASAW\252\002\'Ai.Stigmer.Agentic.Workflowexecution.V1\312\002\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\342\0023Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\352\002+Ai::Stigmer::Agentic::Workflowexecution::V1'
  _globals['_WORKFLOWEXECUTION'].fields_by_name['api_version']._loaded_options = None
  _globals['_WORKFLOWEXECUTION'].fields_by_name['api_version']._serialized_options = b'\272H\031r\027\n\025agentic.stigmer.ai/v1'
  _globals['_WORKFLOWEXECUTION'].fields_by_name['kind']._loaded_options = None
  _globals['_WORKFLOWEXECUTION'].fields_by_name['kind']._serialized_options = b'\272H\025r\023\n\021WorkflowExecution'
  _globals['_WORKFLOWEXECUTION'].fields_by_name['metadata']._loaded_options = None
  _globals['_WORKFLOWEXECUTION'].fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWEXECUTIONSTATUS'].fields_by_name['phase']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONSTATUS'].fields_by_name['phase']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_WORKFLOWTASK'].fields_by_name['task_type']._loaded_options = None
  _globals['_WORKFLOWTASK'].fields_by_name['task_type']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_WORKFLOWTASK'].fields_by_name['status']._loaded_options = None
  _globals['_WORKFLOWTASK'].fields_by_name['status']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_WORKFLOWEXECUTION']._serialized_start=403
  _globals['_WORKFLOWEXECUTION']._serialized_end=794
  _globals['_WORKFLOWEXECUTIONSTATUS']._serialized_start=797
  _globals['_WORKFLOWEXECUTIONSTATUS']._serialized_end=1347
  _globals['_WORKFLOWTASK']._serialized_start=1350
  _globals['_WORKFLOWTASK']._serialized_end=1848
# @@protoc_insertion_point(module_scope)
