# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/environment/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/environment/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/agentic/environment/v1/spec.proto\x12!ai.stigmer.agentic.environment.v1\"\xf3\x01\n\x0f\x45nvironmentSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12P\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32<.ai.stigmer.agentic.environment.v1.EnvironmentSpec.DataEntryR\x04\x64\x61ta\x1al\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12I\n\x05value\x18\x02 \x01(\x0b\x32\x33.ai.stigmer.agentic.environment.v1.EnvironmentValueR\x05value:\x02\x38\x01\"g\n\x10\x45nvironmentValue\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x1b\n\tis_secret\x18\x02 \x01(\x08R\x08isSecret\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scriptionB\xdb\x01\n%com.ai.stigmer.agentic.environment.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAE\xaa\x02!Ai.Stigmer.Agentic.Environment.V1\xca\x02!Ai\\Stigmer\\Agentic\\Environment\\V1\xe2\x02-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Agentic::Environment::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.environment.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.agentic.environment.v1B\tSpecProtoP\001\242\002\004ASAE\252\002!Ai.Stigmer.Agentic.Environment.V1\312\002!Ai\\Stigmer\\Agentic\\Environment\\V1\342\002-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\352\002%Ai::Stigmer::Agentic::Environment::V1'
  _globals['_ENVIRONMENTSPEC_DATAENTRY']._loaded_options = None
  _globals['_ENVIRONMENTSPEC_DATAENTRY']._serialized_options = b'8\001'
  _globals['_ENVIRONMENTSPEC']._serialized_start=84
  _globals['_ENVIRONMENTSPEC']._serialized_end=327
  _globals['_ENVIRONMENTSPEC_DATAENTRY']._serialized_start=219
  _globals['_ENVIRONMENTSPEC_DATAENTRY']._serialized_end=327
  _globals['_ENVIRONMENTVALUE']._serialized_start=329
  _globals['_ENVIRONMENTVALUE']._serialized_end=432
# @@protoc_insertion_point(module_scope)
