# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/rpcauthorization/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/rpcauthorization/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__kind__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import iam_permission_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_iam__permission__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ai/stigmer/iam/iampolicy/v1/rpcauthorization/io.proto\x12,ai.stigmer.iam.iampolicy.v1.rpcauthorization\x1a\x46\x61i/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/iam_permission.proto\"\xf1\x02\n\x16RpcAuthorizationConfig\x12\x66\n\npermission\x18\x01 \x01(\x0e\x32\x46.ai.stigmer.iam.iampolicy.v1.rpcauthorization.ApiResourceIamPermissionR\npermission\x12\x64\n\rresource_kind\x18\x02 \x01(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindR\x0cresourceKind\x12,\n\x12resource_kind_path\x18\x03 \x01(\tR\x10resourceKindPath\x12\x1d\n\nfield_path\x18\x04 \x01(\tR\tfieldPath\x12\x1b\n\terror_msg\x18\x05 \x01(\tR\x08\x65rrorMsg\x12\x1f\n\x0bresource_id\x18\x06 \x01(\tR\nresourceIdB\x93\x02\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\x07IoProtoP\x01\xa2\x02\x06\x41SIIVR\xaa\x02,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\xca\x02,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\xe2\x02\x38\x41i\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\xea\x02\x31\x41i::Stigmer::Iam::Iampolicy::V1::Rpcauthorizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.rpcauthorization.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\007IoProtoP\001\242\002\006ASIIVR\252\002,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\312\002,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\342\0028Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\352\0021Ai::Stigmer::Iam::Iampolicy::V1::Rpcauthorization'
  _globals['_RPCAUTHORIZATIONCONFIG']._serialized_start=243
  _globals['_RPCAUTHORIZATIONCONFIG']._serialized_end=612
# @@protoc_insertion_point(module_scope)
