# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/rpc/pagination.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/rpc/pagination.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ai/stigmer/commons/rpc/pagination.proto\x12\x16\x61i.stigmer.commons.rpc\"0\n\x08PageInfo\x12\x10\n\x03num\x18\x01 \x01(\x05R\x03num\x12\x12\n\x04size\x18\x02 \x01(\x05R\x04size\"C\n\x0eGooglePageInfo\x12\x1d\n\npage_token\x18\x01 \x01(\tR\tpageToken\x12\x12\n\x04size\x18\x02 \x01(\x05R\x04sizeB\xa9\x01\n\x1a\x63om.ai.stigmer.commons.rpcB\x0fPaginationProtoP\x01\xa2\x02\x04\x41SCR\xaa\x02\x16\x41i.Stigmer.Commons.Rpc\xca\x02\x16\x41i\\Stigmer\\Commons\\Rpc\xe2\x02\"Ai\\Stigmer\\Commons\\Rpc\\GPBMetadata\xea\x02\x19\x41i::Stigmer::Commons::Rpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.rpc.pagination_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.ai.stigmer.commons.rpcB\017PaginationProtoP\001\242\002\004ASCR\252\002\026Ai.Stigmer.Commons.Rpc\312\002\026Ai\\Stigmer\\Commons\\Rpc\342\002\"Ai\\Stigmer\\Commons\\Rpc\\GPBMetadata\352\002\031Ai::Stigmer::Commons::Rpc'
  _globals['_PAGEINFO']._serialized_start=67
  _globals['_PAGEINFO']._serialized_end=115
  _globals['_GOOGLEPAGEINFO']._serialized_start=117
  _globals['_GOOGLEPAGEINFO']._serialized_end=184
# @@protoc_insertion_point(module_scope)
