from ai.stigmer.commons.apiresource import io_pb2 as _io_pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as _rpc_service_options_pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as _method_options_pb2
from ai.stigmer.tenancy.project.v1 import api_pb2 as _api_pb2
from ai.stigmer.tenancy.project.v1 import io_pb2 as _io_pb2_1
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
