# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/tasks/try.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/tasks/try.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflow.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_workflow_dot_v1_dot_spec__pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ai/stigmer/agentic/workflow/v1/tasks/try.proto\x12$ai.stigmer.agentic.workflow.v1.tasks\x1a)ai/stigmer/agentic/workflow/v1/spec.proto\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1b\x62uf/validate/validate.proto\"\xb0\x01\n\rTryTaskConfig\x12H\n\x03try\x18\x01 \x03(\x0b\x32,.ai.stigmer.agentic.workflow.v1.WorkflowTaskB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x03try\x12\x46\n\x05\x63\x61tch\x18\x02 \x01(\x0b\x32\x30.ai.stigmer.agentic.workflow.v1.tasks.CatchBlockR\x05\x63\x61tch:\r\xea\x8b,\ttry_catch\"d\n\nCatchBlock\x12\x0e\n\x02\x61s\x18\x01 \x01(\tR\x02\x61s\x12\x46\n\x02\x64o\x18\x02 \x03(\x0b\x32,.ai.stigmer.agentic.workflow.v1.WorkflowTaskB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x02\x64oB\xec\x01\n(com.ai.stigmer.agentic.workflow.v1.tasksB\x08TryProtoP\x01\xa2\x02\x06\x41SAWVT\xaa\x02$Ai.Stigmer.Agentic.Workflow.V1.Tasks\xca\x02$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\xea\x02)Ai::Stigmer::Agentic::Workflow::V1::Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.tasks.try_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.workflow.v1.tasksB\010TryProtoP\001\242\002\006ASAWVT\252\002$Ai.Stigmer.Agentic.Workflow.V1.Tasks\312\002$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\342\0020Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\352\002)Ai::Stigmer::Agentic::Workflow::V1::Tasks'
  _globals['_TRYTASKCONFIG'].fields_by_name['try']._loaded_options = None
  _globals['_TRYTASKCONFIG'].fields_by_name['try']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_TRYTASKCONFIG']._loaded_options = None
  _globals['_TRYTASKCONFIG']._serialized_options = b'\352\213,\ttry_catch'
  _globals['_CATCHBLOCK'].fields_by_name['do']._loaded_options = None
  _globals['_CATCHBLOCK'].fields_by_name['do']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_TRYTASKCONFIG']._serialized_start=213
  _globals['_TRYTASKCONFIG']._serialized_end=389
  _globals['_CATCHBLOCK']._serialized_start=391
  _globals['_CATCHBLOCK']._serialized_end=491
# @@protoc_insertion_point(module_scope)
